*TUBE LIBRARY

* This library was developed by Norman Koren.
*
* For details, refer to the article, "Improved Vacuum-Tube Models
* for SPICE simulations," Glass Audio, Vol. 8, No. 5, 1996,
* available from Audio Amateur Corporation, 305 Union St.,
* PO Box 176, Peterborough, NH 03458 USA.  Phone 603-924-9464.
*
* All the usual legal disclaimers apply.  The author has made
* every effort to provide correct information, but assumes no
* liabilities for errors, misuse of the models,
* or inevitable changes made by users.
*
* The author welcomes your comments, stories, and questions
* (if they don't require too much effort to answer).  For really
* BIG stuff, he will consider consulting for a fee.
* Please contact Norman Koren by Email at kormar@cts.com.
*
* Some models are commented out because the evaluation version of
* Pspice has a maximum of twenty.
*
******************
*
* 1. modified pentode model to work with native LTspice Tetrode symbols.
* 2. added the two new pentode models
* 3. updated the triode model to include the VCT variable (contact potential)
* 4. modified to use sub circuits to save space.
* 5. Added loads more valves.
* 6. JJ valves have their own section
* 7. Svetlana valves have their own section
* 8. US and european valves are now in sections of similar types
* 9. Original Koren models retained with _OLD appended
* 10. All new data samples from the data sheets where available.
* 11. WW2 Luftwafe valves in there own section
* 12. Added various rectifiers and signl diodes. All new
*     samples where data sheets still exist parts 5V4 data
*     <C> Charles Rydel. 5y4 data <c> Stefano Perugini. 2012/05/07
* 13. 28 November 2013
*     NEW: a Hexode / Heptode model. It is not fantastically accurate but
*     it is as far as I know the only Hexode / Heptode model out there and
*     it does work.
*     Added:
*     Hexode:   EH900S, 5915, EH90, E91H, EH960 models.
* 14. 20 April 2014
*     Written separate MatLab solver for thermionic diodes.
*     Added:
*     Triodes:  30, 31, 814, 6N7, RL12T1, RL12T2, RL12T15, RL12T75, RL2_4T1
*               RL2_4T4, LD1, LD2, LD5, RD12Tf
*     Pentodes: RV12P2000, RV12P2001, RV12P3000, RV12P4000
*     Diodes:   RG2_4D1, RG2_4D10, RG12D2, RG12D3, RG12D60, RG12D300
*     Fixed:    Bug in Pentode2 Model
*               Error in EH90 model
*
* Suusi Malcolm-Brown May 2008 - 20 April 2014
*
* All the newer models are generated via a modified version of Norman Koren's
* matlab solver.
*
* NOTE Just because AKA does not mean that they are exact replacements. In
* this case AKA is refering to electrically the same as. As in the Valve
* charicteristic is the same. No Guarantees, totally at the user's own risk.
*
******************

********************
* Rectifier Diodes *
********************

******************
.SUBCKT 5AR4  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law) AKA GZ34
* Philips / Mullard Data Book 1970  12-May-2008
X1 1 2 3 DULEREC G=3.961806m
.ENDS    5AR4

******************
.SUBCKT 5U4GB  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law)
* GE Data Sheet  13-May-2008
X1 1 2 3 DULEREC G=0.783455m
.ENDS    5U4GB

******************
.SUBCKT 5V3  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law)
* GE Data Sheet  12-May-2008
X1 1 2 3 DULEREC G=1.092358m
.ENDS    5V3

******************
.SUBCKT 5V3A  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law)
* TUNG-SOL Data sheet  14-May-2008
X1 1 2 3 DULEREC G=1.285855m
.ENDS    5V3A

******************
.SUBCKT 5V4 1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law)
* Charles Rydel - ; original data retained as no 5V4 data sheet can be found
X1 1 2 3 DULEREC G=1.76m
.ENDS	5V4

******************
.SUBCKT 5V4G  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law) AKA GZ31
* TUNG-SOL Data Sheet  12-May-2008
X1 1 2 3 DULEREC G=1.480822m
.ENDS    5V4G

******************
.SUBCKT 5V4GA  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law)
* GE Data Sheet  12-May-2008
X1 1 2 3 DULEREC G=1.397165m
.ENDS    5V4GA

******************
.SUBCKT 5V4GB  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law) AKA GZ32
* La Radotechnique  12-May-2008
X1 1 2 3 DULEREC G=1.659731m
.ENDS    5V4GB

******************
.SUBCKT 5Y3GT  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law)
* GE Data Sheet  12-May-2008
X1 1 2 3 DULEREC G=0.352292m
.ENDS    5Y3GT

******************
.SUBCKT 5Y4G  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law)
* Stefano Perugini
X1 1 2 3 DULEREC G=0.27567876m
.ENDS    5Y4G

******************
.SUBCKT 5Y4GA  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law)
* Stefano Perugini
X1 1 2 3 DULEREC G=0.27567876m
.ENDS    5Y4GA

******************
.SUBCKT 5Y4GT  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law)
* Stefano Perugini
X1 1 2 3 DULEREC G=0.27567876m
.ENDS    5Y4GT

******************
.SUBCKT 6AL5  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law)
* GE Data Sheet  12-May-2008
X1 1 2 3 DULEREC G=1.961727m
.ENDS    6AL5

******************
.SUBCKT 6V4  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law) AKA EZ80
* Philips data book  12-May-2008
X1 1 2 3 DULEREC G=0.730451m
.ENDS    6V4

******************
.SUBCKT 6X4  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law) AKA EZ90
* Universal Electronic VadeMecum  14-May-2008
X1 1 2 3 DULEREC G=0.702260m
.ENDS    6X4

******************
.SUBCKT 6X5  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law) AKA EZ90 (electrically identical to 6X4 and 12X4 )
* Universal Electronic VadeMecum  14-May-2008
X1 1 2 3 DULEREC G=0.702260m
.ENDS    6X5

******************
.SUBCKT 12X4  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law)
* Universal Electronic VadeMecum  14-May-2008
X1 1 2 3 DULEREC G=0.702260m
.ENDS    12X4



**************************
* Triode Output Pentodes *
**************************

******************
.SUBCKT 6AB8T  1 2 3 ; P G C (Triode)  ; TRIODE SECTION
* Call Equiverlent AKA ECL80
X1 1 2 3 ECL80T ; same as ECL80T
.ENDS    6AB8T

******************
.SUBCKT 6AB8P 1 2 3 4 ; A G2 G1 C (Pentode)	; PENTODE SECTION
* Call Equiverlent AKA ECL80
X1 1 2 3 4 ECL80P ; same as ECL80P
.ENDS	6AB8P

******************
.SUBCKT 6BM8T  1 2 3 ; P G C (Triode)  ; TRIODE SECTION
* Call Equiverlent AKA ECL82
X1 1 2 3 ECL82T ; same as ECL82T
.ENDS    6BM8T

******************
.SUBCKT 6BM8P 1 2 3 4 ; A G2 G1 C (Pentode)	; PENTODE SECTION
* Call Equiverlent AKA ECL82
X1 1 2 3 4 ECL82P ; same as ECL82P
.ENDS	6BM8P

******************
.SUBCKT 6DX8T  1 2 3 ; P G C (Triode)  ; TRIODE SECTION
* Call Equiverlent AKA ECL84
X1 1 2 3 ECL84T ; same as ECL84T
.ENDS    6DX8T

******************
.SUBCKT 6DX8P 1 2 3 4 ; A G2 G1 C (Pentode)	; PENTODE SECTION
* Call Equiverlent AKA ECL84
X1 1 2 3 4 ECL84P ; same as ECL84P
.ENDS	6DX8P

******************
.SUBCKT 6GV8T  1 2 3 ; P G C (Triode)  ; TRIODE SECTION
* Call Equiverlent AKA ECL85
X1 1 2 3 ECL85T ; same as ECL85T
.ENDS    6GV8T

******************
.SUBCKT 6GV8P 1 2 3 4 ; A G2 G1 C (Pentode)	; PENTODE SECTION
* Call Equiverlent AKA ECL85
X1 1 2 3 4 ECL85P ; same as ECL85P
.ENDS	6GV8P

******************
.SUBCKT 6GW8T  1 2 3 ; P G C (Triode)  ; TRIODE SECTION
* Call Equiverlent AKA ECL86
X1 1 2 3 ECL86T ; same as ECL86T
.ENDS    6GW8T

******************
.SUBCKT 6GW8P 1 2 3 4 ; A G2 G1 C (Pentode)	; PENTODE SECTION
* Call Equiverlent AKA ECL86
X1 1 2 3 4 ECL86P ; same as ECL86P
.ENDS	6GW8P

********************************
* Triode small signal Pentodes *
********************************

******************
* model by Eugene V. Karpov
*
.SUBCKT 6C45P-E  1 2 3 ; P G C (Triode) 23-Oct-2006
+ PARAMS: MU= 53.57  EX= 1.957  KG1= 126.6  KP= 368.51 
+ KVB= 300.0  VCT= 0.00 RGI=1000
+ CCG=11P  CGP=5P CCP=1.9P
E1 7 0 VALUE=
+{V(1,3)/KP*LN(1+EXP(KP*(1/MU+(V(2,3)+VCT)/SQRT(KVB+V(1,3)*V(1,3)))))}
RE1 7 0 1G
G1 1 3 VALUE={(PWR(V(7),EX)+PWRS(V(7),EX))/KG1}
RCP 1 3 1G    ; TO AVOID FLOATING NODES IN MU-FOLLOWER
C1 2 3 {CCG}  ; CATHODE-GRID; 
C2 2 1 {CGP}  ; GRID-PLATE; 
C3 1 3 {CCP}  ; CATHODE-PLATE; 
D3 5 3 DX     ; FOR GRID CURRENT
R1 2 5 {RGI}  ; FOR GRID CURRENT
.MODEL DX D(IS=1N RS=1 CJO=10PF TT=1N)
.ENDS

******************
* ==============================================================
* 6C45Pi PSpice model
* Joel Tunnah
* ==============================================================
.subckt 6C45Pi-j P G K
  Gp P K VALUE=
+ {(0.005984658048m)*limit(V(P,K)*ln(1.0+(0.02028899001)+exp((7.114994862)+
+ (7.114994862)*((56.68678595)+(336.3011671m)*V(G,K))*V(G,K)/sqrt((7.450118654e-006)**2+
+ (V(P,K)-(-10.58802286))**2)))/(7.114994862),0.0,1.0e16)**(1.976888442)}
  Cgp G P 4p
  Cgk G K 11p
  Cpk P K 1.9p
  Rpk P K 1G ; to avoid floating nodes
  d3  G K dx1
.model dx1 d(is=1n rs=2k cjo=1pf N=1.5 tt=1n)
.ends 6C45Pi-j

******************
* ==============================================================
* 6C45Pisb PSpice model
* Steve Bench
* ==============================================================
.subckt 6C45-PE 1 2 3 ; plate grid cathode
+ params: mu=47.4501 ex=2.374193 kg1=268.615545 kp=485.735371 kvb=501.503636 rgi=300
+ ccg=2.4p cgp=4p ccp=.7p
e1 7 0 value= {v(1,3)/kp*log(1+exp(kp*(1/mu+v(2,3)/sqrt(kvb+v(1,3)*v(1,3)))))}
re1 7 0 1g
g1 1 3 value= {(pwr(v(7),ex)+pwrs(v(7),ex))/kg1}
rcp 1 3 1g
c1 2 3 {ccg}
c2 1 2 {cgp}
c3 1 3 {ccp}
r1 2 5 {rgi}
d3 5 3 dx
.model dx d(is=1n rs=1 cjo=10pf tt=1n)
.ends

******************
* 437A  -  IDH miniature high-transconductance triode Andrei Frolov
* Gp  P K  VALUE={(m)*limit(()*V(G,K)+V(P,K),0.0,1.0e16)^1.5}
* From WE 437A datasheet - traced on 24-03-02 by AF
.subckt 437A  P G K
    Cgp G P  3.8p
    Ci  G K  11.1p
    Co  P K  1.0p
* Modified Koren model (8 parameters): mean fit error 1.94219 mA
    Gp  P K  VALUE=
+ {(0.04402840226m)*limit(V(P,K)*log(1.0+(-0.3253203784)+exp((2.359465245)+
+ (2.359465245)*((38.12689842)+(-2617.293976m)*V(G,K))*V(G,K)/sqrt((54.35117386)^2+
+ (V(P,K)-(41.98740594))^2)))/(2.359465245),0.0,1.0e16)^(1.633336782)}
.ends 437A

******************
.SUBCKT 7199T  1 2 3 ; P G C (Triode) ; TRIODE SECTION
* RCA
* library format: LTSpice 01-Jun-2008
X1 1 2 3 TRIODE MU=32.71 EX=1.284 KG1=534.8 KP=52.95 KVB=300.0 VCT=0.00 RGI=2000 CCG=3.0p CGP=2.5p CCP=1.0p ;
.ENDS    7199T

******************
.SUBCKT 7199P_ 1 2 3 4 ; A G2 G1 C (PENTODE)
* RCA
* library format: LTSpice 17-Apr-2010
X1 1 2 3 4 PENTODE1 MU=71.79 EX=1.350 KG1=455.5 KG2=329 KP=85.38 KVB=1.0 K4=2.19 VCT=0.00 RGI=2000 CCG=5.7p CPG1=0.6p CCP=2.5p ;
.ENDS    7199P_

******************
.SUBCKT 7199P  1 2 3 4 ; A G2 G1 C (PENTODE)
* Sylvania
* library format: LTSpice 24-Nov-2013
X1 1 2 3 4 PENTODE1 MU=95.39 EX=0.920 KG1=222.5 KG2=119 KP=860 KVB=19.1 VCT=0.00 RGI=2000 CCG=5.7p CPG1=0.560p CCP=2.5p ;
.ENDS    7199P

******************
.SUBCKT 6AN8T_OLD 1 2 3  ; A G C (Triode)  ; TRIODE SECTION
* Original Koren Lib
X1 1 2 3 TRIODE MU=21.2 EX=1.36 KG1=945 KP=84 KVB=300 RGI=2000 CCG=2.7P CGP=2.2P CCP=1.0P	; ADD .7PF TO ADJACENT PINS; .5 TO OTHERS.
.ENDS	6AN8T

******************
.SUBCKT 6AN8P_OLD 1 2 3 4 ; A G2 G1 C (Pentode)	; PENTODE SECTION
* Original Koren Lib
X1 1 2 3 4 PENTODE MU=45 EX=1.35 KG1=520 KG2=120 KP=120 KVB=18 CCG=8P CPG1=.8P CCP=3P RGI=2K
.ENDS	6AN8P

******************
.SUBCKT 6AN8T  1 2 3 ; P G C (Triode) ; TRIODE SECTION
* Sylvania Data sheet
* library format: LTSpice 01-Jun-2008
X1 1 2 3 TRIODE MU=25.23 EX=1.350 KG1=772.2 KP=65.20 KVB=300.0 VCT=0.00 RGI=2000 CCG=2.7p CGP=2.2p CCP=0.8p ;
.ENDS    6AN8T

******************
.SUBCKT 6AN8P  1 2 3 4 ; A G2 G1 C (Pentode)	; PENTODE SECTION
* Sylvania Data sheet
* library format: LTSpice 01-Jun-2008
X1 1 2 3 4 PENTODE1 MU=47.04 EX=1.350 KG1=487.2 KG2=4500 KP=113.02 KVB=17.0 VCT=0.00 RGI=2000 CCG=5.7p CPG1=0.6p CCP=2.5p ;
.ENDS    6AN8P

******************
.SUBCKT 6AX8T  1 2 3 ; P G C (Triode)  ; TRIODE SECTION
* Call Equiverlent
X1 1 2 3 ECF80T ; same as ECF 80
.ENDS    6AX8T

******************
.SUBCKT 6AX8P 1 2 3 4 ; A G2 G1 C (Pentode)	; PENTODE SECTION
* Call Equiverlent
X1 1 2 3 4 ECF80P ; same as ECF 80
.ENDS	6AX8P

******************
.SUBCKT 6BL8T  1 2 3 ; P G C (Triode)  ; TRIODE SECTION
* Call Equiverlent
X1 1 2 3 ECF80T ; same as ECF 80
.ENDS    6BL8T

******************
.SUBCKT 6BL8P 1 2 3 4 ; A G2 G1 C (Pentode)	; PENTODE SECTION
* Call Equiverlent
X1 1 2 3 4 ECF80P ; same as ECF 80
.ENDS	6BL8P

******************
.SUBCKT 6U8T  1 2 3 ; P G C (Triode)  ; TRIODE SECTION
* Call Equiverlent
X1 1 2 3 ECF82T ; same as ECF 82
.ENDS    6U8T

******************
.SUBCKT 6U8P 1 2 3 4 ; A G2 G1 C (Pentode)	; PENTODE SECTION
* Call Equiverlent
X1 1 2 3 4 ECF82P ; same as ECF 82
.ENDS	6U8P

******************
.SUBCKT 6HG8T  1 2 3 ; P G C (Triode)  ; TRIODE SECTION
* Call Equiverlent
X1 1 2 3 ECF86T ; same as ECF 86
.ENDS    6HG8T

******************
.SUBCKT 6HG8P 1 2 3 4 ; A G2 G1 C (Pentode)	; PENTODE SECTION
* Call Equiverlent
X1 1 2 3 4 ECF86P ; same as ECF 86
.ENDS	6HG8P

************************
* Small Signal Triodes *
************************

******************
.SUBCKT 30  1 2 3 ; P G C (Triode)
* TUNG-SOL Data sheet
* library format: LTSpice 20-Apr-2014
X1 1 2 3 TRIODE MU=9.08 EX=1.779 KG1=16126.7 KP=192.81 KVB=300.0 VCT=0.00 RGI=2000 CCG=17.0p CGP=8.2p CCP=6.0p ;
.ENDS    30

******************
.SUBCKT 31  1 2 3 ; P G C (Triode)
* RCA Data sheet
* library format: LTSpice 20-Apr-2014
X1 1 2 3 TRIODE MU=3.76 EX=1.511 KG1=12765.0 KP=49.02 KVB=300.0 VCT=0.00 RGI=2000 CCG=3.5p CGP=5.7p CCP=2.7p ;
.ENDS    31

******************
.SUBCKT 76  1 2 3 ; P G C (Triode)
* TUNG SOL + RCA data sheet
* library format: LTSpice 18-Nov-2009
X1 1 2 3 TRIODE MU=14.04 EX=1.269 KG1=2501.1 KP=202.50 KVB=300.0 VCT=0.00 RGI=2000 CCG=2.3p CGP=2.2p CCP=1.0p ;
.ENDS    76

******************
.SUBCKT 6N7  1 2 3 ; P G C (Triode)
* GE 6N7
* library format: LTSpice 30-Mar-2014
X1 1 2 3 TRIODE MU=35.96 EX=1.248 KG1=1611.4 KP=235.00 KVB=300.0 VCT=0.00 RGI=2000 CCG=2.3p CGP=2.2p CCP=1.0p ;
.ENDS    6N7

******************
.SUBCKT 6R4 2 3 ; P G C (Triode)
* Mullard data book 1968 AKA EC81
* library format: LTSpice 18-Sep-2011
* Call Equiverlent
X1 1 2 3 4 EC81 ; same as EC 81
.ENDS    6R4

******************
.SUBCKT 5670  1 2 3 ; P G C (Triode)
* RCA Data Sheet
* library format: LTSpice 02-May-2012
X1 1 2 3 TRIODE MU=32.76 EX=1.619 KG1=1359.4 KP=211.19 KVB=47.0 VCT=0.40 RGI=2000 CCG=2.3p CGP=2.4p CCP=0.9p ;
.ENDS    5670

******************
.SUBCKT 5751  1 2 3 ; P G C (Triode)
* GE Data Sheet
* library format: LTSpice 18-Nov-2009
X1 1 2 3 TRIODE MU=84.75 EX=1.291 KG1=1137.3 KP=415.40 KVB=1515.2 VCT=0.40 RGI=2000 CCG=2.3p CGP=2.4p CCP=0.9p ;
.ENDS    5751

******************
.SUBCKT 5965  1 2 3 ; P G C (Triode)
* Tung Sol Data Sheet AKA 12AV7
* library format: LTSpice 08-Apr-2012
X1 1 2 3 4 12AV7 ; same as 12AV7
.ENDS    5965

******************
.SUBCKT 6072  1 2 3 ; P G C (Triode)
* Tung Sol Data Sheet AKA 12AY7
* library format: LTSpice 08-Apr-2012
X1 1 2 3 4 12AY7 ; same as 12AY7
.ENDS    6072

******************
.SUBCKT 6922 1 2 3 ; A G C (Triode)	AKA E88CC
* Mullard
X1 1 2 3 TRIODE MU=31.75 EX=1.177 KG1=233.1 KP=288.17 KVB=83.4 VCT=0.00 RGI=2000 CCG=2.3P CGP=2.4P CCP=.9P	; ADD .7PF TO ADJACENT PINS; .5 TO OTHERS.
.ENDS	6922

******************
.SUBCKT 7025  1 2 3 ; P G C (Triode)
* Sylvania Technical Manual
* library format: LTSpice 02-Jun-2008
X1 1 2 3 TRIODE MU=102.50 EX=1.409 KG1=1598.8 KP=813.82 KVB=44.9 VCT=0.50 RGI=2000 CCG=2.3p CGP=2.4p CCP=0.9p ;
.ENDS    7025

******************
.SUBCKT 6CG7  1 2 3 ; P G C (Triode)
* GE Data Sheet 1963
* library format: LTSpice 02-Jun-2008
X1 1 2 3 TRIODE MU=21.86 EX=1.319 KG1=1248.5 KP=140.12 KVB=300.0 VCT=0.00 RGI=2000 CCG=2.9p CGP=4.7p CCP=2.7p ;
.ENDS    6CG7

******************
.SUBCKT 6DJ8_OLD 1 2 3 ; A G C	(Triode) ;
* Original Koren Lib
X1 1 2 3 TRIODE MU=28 EX=1.3 KG1=330 KP=320 KVB=300 RGI=2000 CCG=2.3P  CGP=2.1P CCP=.7P  ; ADD .7PF TO ADJACENT PINS; .5 TO OTHERS.
.ENDS	6DJ8_OLD

******************
.SUBCKT 6DJ8 1 2 3 ; A G C	(Triode) ;
* Tom Mitchell
X1 1 2 3 TRIODE MU=30.51 EX=1.532 KG1=453.9 KP=233.17 KVB=190.9 VCT=0.50  RGI=2000 CCG=2.3P  CGP=2.1P CCP=.7P  ; ADD .7PF TO ADJACENT PINS; .5 TO OTHERS.
.ENDS	6DJ8

******************
.SUBCKT 6SL7GT  1 2 3 ; P G C (Triode)
* GE
* library format: LTSpice 01-Jun-2008
X1 1 2 3 TRIODE MU=75.89 EX=1.233 KG1=1735.2 KP=1725.27 KVB=7.0 VCT=0.50 RGI=2000 CCG=2.9p CGP=4.1p CCP=1.5p ;
.ENDS    6SL7GT

******************
.SUBCKT 6SN7  1 2 3 ; P G C (Triode)
* Sylvania Technical Manual
* library format: LTSpice 01-Jun-2008
X1 1 2 3 TRIODE MU=21.07 EX=1.341 KG1=1446.2 KP=157.81 KVB=179.4 VCT=0.00 RGI=2000 CCG=3.1p CGP=4.7p CCP=1.4p ;
.ENDS    6SN7

******************
.SUBCKT 6SN7GTA  1 2 3 ; P G C (Triode)
* Sylvania data sheet
* library format: LTSpice 01-Jun-2008
X1 1 2 3 TRIODE MU=21.54 EX=1.316 KG1=1261.1 KP=156.78 KVB=296.4 VCT=0.00 RGI=2000 CCG=3.1p CGP=4.7p CCP=1.4p ;
.ENDS    6SN7GTA

******************
.SUBCKT 6SN7GTB  1 2 3 ; P G C (Triode)
* Sylvania
* library format: LTSpice 01-Jun-2008
X1 1 2 3 TRIODE MU=21.54 EX=1.316 KG1=1261.1 KP=156.78 KVB=296.4 VCT=0.00 RGI=2000 CCG=3.1p CGP=4.7p CCP=1.4p ;
.ENDS    6SN7GTB

******************
.SUBCKT 12AT7_OLD 1 2 3 ; A G C	(Triode)	AKA ECC81
* Original Koren Model
X1 1 2 3 TRIODE MU=60 EX=1.35 KG1=460 KP=300 KVB=300 VCT=0.00 RGI=2000 CCG=2.3P CGP=2.2P CCP=1.0P  ; ADD .7PF TO ADJACENT PINS; .5 TO OTHERS.
.ENDS	12AT7_OLD

******************
.SUBCKT 12AT7 1 2 3 ; A G C	(Triode)	AKA ECC81
* Tom Mitchell
X1 1 2 3 TRIODE MU=67.49 EX=1.234 KG1=419.1  KP=213.96 KVB= 300.0 VCT=0.00 RGI=2000 CCG=2.3P CGP=2.2P CCP=1.0P	; ADD .7PF TO ADJACENT PINS; .5 TO OTHERS.
.ENDS	12AT7

******************
.SUBCKT 12AT7WA  1 2 3 ; P G C (Triode)
* MAZDA BELVU Data Sheet AKA ECC81
* library format: LTSpice 01-Jun-2008
X1 1 2 3 TRIODE MU=72.80 EX=1.167 KG1=341.8 KP=233.21 KVB=267.8 VCT=0.00 RGI=2000 CCG=2.3p CGP=2.2p CCP=1.0p ;
.ENDS    12AT7WA

******************
.SUBCKT 12AU7_OLD 1 2 3 ; A G C	(Triode)	AKA ECC82
* Original Koren Model
X1 1 2 3 TRIODE MU=21.5 EX=1.3 KG1=1180 KP=84 KVB=300 VCT=0.00 RGI=2000 CCG=2.3P  CGP=2.2P CCP=1.0P  ; ADD .7PF TO ADJACENT PINS; .5 TO OTHERS.
.ENDS	12AU7_OLD

******************
.SUBCKT 12AU7  1 2 3 ; P G C (Triode)
* Sylvania Technical Manual AKA ECC82 ECC802 5814 6067 6189
* library format: LTSpice 01-Jun-2008
X1 1 2 3 TRIODE MU=20.21 EX=1.230 KG1=1108.7 KP=84.96 KVB=551.3 VCT=0.00 RGI=2000 CCG=2.3p CGP=2.2p CCP=1.0p ;
.ENDS    12AU7

******************
.SUBCKT 12AU7A  1 2 3 ; P G C (Triode)
* MAZDA BELVU Data sheet AKA ECC82 ECC802 5814 6067 6189
* library format: LTSpice 01-Jun-2008
X1 1 2 3 TRIODE MU=19.41 EX=1.226 KG1=1233.8 KP=104.87 KVB=300.0 VCT=0.00 RGI=2000 CCG=2.3p CGP=2.2p CCP=1.0p ;
.ENDS    12AU7A

******************
.SUBCKT 12AV7  1 2 3 ; P G C (Triode)
* Tung Sol Data Sheet AKA 5965
* library format: LTSpice 08-Apr-2012
X1 1 2 3 TRIODE MU=39.40 EX=1.265 KG1=484.0 KP=142.49 KVB=363.7 VCT=0.40 RGI=2000 CCG=2.3p CGP=2.4p CCP=0.9p ;
.ENDS    12AV7

******************
.SUBCKT 12AX7_OLD 1 2 3 ; A G C (Triode)  OLD MODEL	AKA ECC83
* Original Koren Model, Use OLD temporarily for article.
X1 1 2 3 TRIODE MU=93 EX=1.5 KG1=1360 KP=10000 KVB=0 VCT=0.00 RGI=2000 CCG=2.3P  CGP=2.4P CCP=.9P	; ADD .7PF TO ADJACENT PINS; .5 TO OTHERS.
.ENDS 12AX7_OLD

******************
.SUBCKT 12AX7 1 2 3 ; A G C	(Triode)  OLD MODEL	AKA ECC83
* Original Koren Model
X1 1 2 3 TRIODE MU=100 EX=1.4 KG1=1060 KP=600 KVB=300 VCT=0.00 RGI=2000 CCG=2.3P CGP=2.4P CCP=.9P	; ADD .7PF TO ADJACENT PINS; .5 TO OTHERS.
.ENDS	12AX7

******************
.SUBCKT 12AX7ASYL  1 2 3 ; P G C (Triode)
* Sylvania Technical Manual 1955 AKA ECC83 12AX7A 7025
* library format: LTSpice 31-May-2008
X1 1 2 3 TRIODE MU=105.78 EX=1.474 KG1=1618.2 KP=432.76 KVB=35.6 VCT=0.50 RGI=2000 CCG=2.3p CGP=2.4p CCP=0.9p ;
.ENDS    12AX7ASYL

******************
.SUBCKT 12AX7A  1 2 3 ; P G C (Triode)
* RCA data sheet AKA ECC83 7025
* library format: LTSpice 31-May-2008
X1 1 2 3 TRIODE MU=100.26 EX=1.394 KG1=1651.8 KP=17950.75 KVB=524.4 VCT=0.50 RGI=2000 CCG=2.3p CGP=2.4p CCP=0.9p ;
.ENDS    12AX7A

******************
.SUBCKT 12AY7  1 2 3 ; P G C (Triode)
* GE data book June 1955
* library format: LTSpice 31-May-2008
X1 1 2 3 TRIODE MU=44.16 EX=1.113 KG1=1192.4 KP=409.96 KVB=300.0 VCT=0.00 RGI=2000 CCG=2.0p CGP=2.0p CCP=1.0p ;
.ENDS    12AY7

******************
.SUBCKT 12AZ7  1 2 3 ; P G C (Triode)
* RCA data sheet AKA 12AT7 ECC81 ECC801 6060 6201 6679
* library format: LTSpice 01-Jun-2008
X1 1 2 3 TRIODE MU=74.08 EX=1.371 KG1=382.0 KP=190.11 KVB=300.0 VCT=0.00 RGI=2000 CCG=2.3p CGP=2.2p CCP=1.0p ;
.ENDS    12AZ7

******************
.SUBCKT 12BH7A  1 2 3 ; P G C (Triode)
* GE Data sheet
* library format: LTSpice 31-May-2008
X1 1 2 3 TRIODE MU=24.59 EX=1.343 KG1=594.4 KP=73.01 KVB=300.0 VCT=0.00 RGI=2000 CCG=3.9p CGP=3.2p CCP=1.1p ;
.ENDS    12BH7A

*************************************
* Small Signal and Vary Mu Pentodes *
*************************************

******************
.SUBCKT 5654 2 3 ; P G C (Triode)
* Tung Sol Data Sheet AKA EF95 6AK5
* library format: LTSpice 14-Apr-2012
X1 1 2 3 4 EF95 ; same as EF95
.ENDS    5654

******************
.SUBCKT 5879  1 2 3 4 ; A G2 G1 C (Pentode)
* RCA data sheet
* library format: LTSpice 14-Nov-2009
X1 1 2 3 4 PENTODE1 MU=22.01 EX=1.395 KG1=3488.1 KG2=4500 KP=117.73 KVB=15.1 VCT=0.00 RGI=2000 CCG=4.3p CPG1=0.6p CCP=5.1p ;
.ENDS    5879

******************
.SUBCKT  6267 1 2 3 4 ; A G2 G1 C (Pentode)
*  same as EF86
X1 1 2 3 4 EF86
.ENDS	6267

******************
.SUBCKT 6AK5 1 2 3 4 ; A G2 G1 C (Pentode)
* Telefunken data sheet  AKA 5654, EF95
* library format: LTSpice 17-Apr-2010
X1 1 2 3 4 EF95 ;
.ENDS    6AK5

******************
.SUBCKT 6AU6  1 2 3 4 ; A G2 G1 C (Pentode)
* GE data sheet AKA EF94 6AU6A
* library format: LTSpice 17-Apr-2010
X1 1 2 3 4 PENTODE1 MU=36.65 EX=1.376 KG1=1129.4 KG2=1059 KP=215.42 KVB=15.0 VCT=0.00 RGI=2000 CCG=4.3p CPG1=0.6p CCP=5.1p ;
.ENDS    6AU6

******************
.SUBCKT 6AU6A  1 2 3 4 ; A G2 G1 C (Pentode)
* GE data sheet AKA EF94 6AU6
* library format: LTSpice 17-Apr-2010
X1 1 2 3 4 6AU6
.ENDS    6AU6A

******************
.SUBCKT  6CF8 1 2 3 4 ; A G2 G1 C (Pentode)
*  same as EF86
X1 1 2 3 4 EF86
.ENDS	6CF8

******************
.SUBCKT  6BK8 1 2 3 4 ; A G2 G1 C (Pentode)
*  same as EF86
X1 1 2 3 4 EF86
.ENDS	6BK8

******************
.SUBCKT  6BY7 1 2 3 4 ; A G2 G1 C (Pentode)
*  same as EF85
X1 1 2 3 4 EF85
.ENDS	6BY7

******************
.SUBCKT  6DA6 1 2 3 4 ; A G2 G1 C (Pentode)
*  same as EF89
X1 1 2 3 4 EF89
.ENDS	6DA6

*****************
* Power Triodes *
*****************

******************
.SUBCKT 300B_OLD 1 2 3 ; A G C	(Triode)
* Original Koren Lib
X1 1 2 3 TRIODE MU=3.95 EX=1.4 KG1=1550 KP=65 KVB=300 VCT=0.00 RGI=1000 CCG=17P CGP=11P CCP=7.5P  ; ADD .7PF TO ADJACENT PINS; .5 TO OTHERS.
.ENDS	300B

******************
.SUBCKT 300B  1 2 3 ; P G C (Triode)
* Western Electric Data sheet 1950
* library format: LTSpice 02-Jun-2008
X1 1 2 3 TRIODE MU=3.92 EX=1.504 KG1=2140.3 KP=64.28 KVB=300.0 VCT=0.00 RGI=1000 CCG=17.0p CGP=11.0p CCP=7.5p ;
.ENDS    300B

******************
.SUBCKT 2A3_OLD 1 2 3 ; A G C	(Triode)
* Original Koren Lib
X1 1 2 3 TRIODE MU=4.2 EX=1.4 KG1=1500 KP=60 KVB=300 RGI=2000 CCG=2.3P  CGP=2.2P CCP=1.0P  ; ADD .7PF TO ADJACENT PINS; .5 TO OTHERS.
.ENDS	2A3

******************
.SUBCKT 2A3  1 2 3 ; P G C (Triode)
* TUNG-SOL Data sheet
* library format: LTSpice 02-Jun-2008
X1 1 2 3 TRIODE MU=4.05 EX=1.634 KG1=3652.2 KP=58.47 KVB=300.0 VCT=0.00 RGI=1000 CCG=17.0p CGP=8.2p CCP=6.0p ;
.ENDS    2A3

************************************
* Power Pentodes and Beam Tetrodes *
************************************

******************
.SUBCKT 814  1 2 3 4 ; A G2 G1 C (Pentode)
* RCA
* library format: LTSpice 20-Apr-2014
X1 1 2 3 4 PENTODE1 MU=9.52 EX=1.350 KG1=2981.5 KG2=9293 KP=421.77 KVB=84.3 VCT=0.00 RGI=1000 CCG=13.5p CPG1=0.150p CCP=13.5p ;
.ENDS    814

******************
.SUBCKT 5881  1 2 3 4 ; A G2 G1 C (Beam Tetrode)
* Tung-Sol Data Book
* library format: LTSpice 02-Jun-2008
X1 1 2 3 4 PENTODE1 MU=8.35 EX=1.484 KG1=2507.1 KG2=4500 KP=53.86 KVB=14.4 VCT=0.00 RGI=1000 CCG=10.0p CPG1=0.6p CCP=6.5p ;
.ENDS    5881

******************
.SUBCKT 6550_OLD 1 2 3 4 ; A G2 G1 C (Beam Tetrode)
* Original Koren Model
X1 1 2 3 4 PENTODE MU=7.9 EX=1.35 KG1=890 KG2=4200 KP=60 KVB=24 CCG=14P CPG1=.85P CCP=12P RGI=1K
.ENDS	6550_OLD

******************
.SUBCKT 6550  1 2 3 4 ; A G2 G1 C (Beam Tetrode)
* Tung-Sol Data Book 1963
* library format: LTSpice 02-Jun-2008
X1 1 2 3 4 PENTODE1 MU=8.61 EX=1.435 KG1=1066.6 KG2=4500 KP=39.55 KVB=20.5 VCT=0.00 RGI=1000 CCG=15.0p CPG1=0.8p CCP=10.0p ;
.ENDS    6550

******************
.SUBCKT 6550A  1 2 3 4 ; A G2 G1 C (Beam Tetrode)
* GE Data sheet 1973
* library format: LTSpice 02-Jun-2008
X1 1 2 3 4 PENTODE1 MU=10.81 EX=1.397 KG1=703.2 KG2=4500 KP=27.68 KVB=19.1 VCT=0.00 RGI=1000 CCG=15.0p CPG1=0.8p CCP=10.0p ;
.ENDS    6550A

******************
.SUBCKT 6686  1 2 3 4 ; A G2 G1 C (Pentode) AKA E81L, EL861
* Philips data sheet
* library format: LTSpice 15-Nov-2009
X1 1 2 3 4 E81L ; CALL E81L
.ENDS    6686

******************
.SUBCKT 6973  1 2 3 4 ; A G2 G1 C (Pentode)
* RCA data sheet
* library format: LTSpice 14-Nov-2009
X1 1 2 3 4 PENTODE1 MU=13.58 EX=1.350 KG1=1142.2 KG2=4500 KP=27.70 KVB=18.4 VCT=0.00 RGI=2000 CCG=4.3p CPG1=0.6p CCP=5.1p ;
.ENDS    6973

******************
.SUBCKT  7027 1 2 3 4 ; A G2 G1 C (Beam Tetrode)
* RCA same as 6L6GC Higher Anode power
X1 1 2 3 4 6L6GC
.ENDS	7027

******************
.SUBCKT  7027A 1 2 3 4 ; A G2 G1 C (Beam Tetrode)
* RCA same as 6L6GC Higher Anode power
X1 1 2 3 4 6L6GC
.ENDS	7027A

******************
.SUBCKT 7189  1 2 3 4 ; A G2 G1 C (Pentode)
* Mullard Data Sheet AKA 6BQ5 EL84 N709
* library format: LTSpice 02-Jun-2008
X1 1 2 3 4 6BQ5 ; call 6BQ5
.ENDS    7189

******************
.SUBCKT  7581 1 2 3 4 ; A G2 G1 C (Beam Tetrode)
* Tung-Sol same as 6L6GC Higher Anode power
X1 1 2 3 4 6L6GC
.ENDS	7581

******************
.SUBCKT  7581A 1 2 3 4 ; A G2 G1 C (Beam Tetrode)
* Tung-Sol same as 6L6GC Higher Anode power
X1 1 2 3 4 6L6GC
.ENDS	7581A

******************
.SUBCKT  7591A 1 2 3 4 ; A G2 G1 C (Beam Tetrode)
* Tung-Sol same as 6L6GC Higher Anode power
X1 1 2 3 4 7868 ; call 7868
.ENDS	7581A

******************
.SUBCKT 7868  1 2 3 4 ; A G2 G1 C (Pentode)
* RCA data sheet
* library format: LTSpice 24-Nov-2009
X1 1 2 3 4 PENTODE1 MU=25.18 EX=1.350 KG1=401.2 KG2=4500 KP=55.60 KVB=24.9 VCT=0.00 RGI=2000 CCG=4.3p CPG1=0.6p CCP=5.1p ;
.ENDS    7868

******************
.SUBCKT 6BQ5  1 2 3 4 ; A G2 G1 C (Pentode)
* Mullard Data Sheet AKA 7189 EL84 N709
* library format: LTSpice 02-Jun-2008
X1 1 2 3 4 PENTODE1 MU=21.29 EX=1.240 KG1=401.7 KG2=4500 KP=111.04 KVB=17.9 VCT=0.00 RGI=1000 CCG=10.0p CPG1=0.6p CCP=5.1p ;
.ENDS    6BQ5

******************
.SUBCKT 6CA7_OLD 1 2 3 4 ; A G2 G1 C (Pentode) AKA EL34
* Original Original Koren Model
X1 1 2 3 4 PENTODE MU=11 EX=1.35 KG1=650 KG2=4200 KP=60 KVB=24 CCG=15P CPG1=1P CCP=8P RGI=1K
.ENDS	6CA7_OLD

******************
.SUBCKT 6CA7 1 2 3 4 ; A G2 G1 C (Pentode) AKA EL34
* Mullard
X1 1 2 3 4 EL34 ; call the el34
.ENDS	6CA7

******************
.SUBCKT 6CK5  1 2 3 4 ; A G2 G1 C (Pentode) AKA EL41 BF61 N150 6CK5
* Philips data sheet
* library format: LTSpice 16-Nov-2009
X1 1 2 3 4 EL80 ; Call EL80
.ENDS    6CK5

******************
.SUBCKT 6CL6  1 2 3 4 ; A G2 G1 C (PENTODE)
* RCA
* library format: LTSpice 12-Oct-2011
X1 1 2 3 4 PENTODE1 MU=20.64 EX=1.351 KG1=469.3 KG2=812 KP=159.49 KVB=67.9 VCT=0.00 RGI=2000 CCG=5.7p CPG1=0.560p CCP=2.5p ;
.ENDS    6CL6

******************
.SUBCKT 6EH5  1 2 3 4 ; A G2 G1 C (Pentode)
* GE data sheet
* library format: LTSpice 14-Nov-2009
X1 1 2 3 4 PENTODE1 MU=16.46 EX=1.350 KG1=415.4 KG2=4500 KP=85.16 KVB=13.4 VCT=0.00 RGI=2000 CCG=4.3p CPG1=0.6p CCP=5.1p ;
.ENDS    6EH5

******************
.SUBCKT 6L6GB 1 2 3 4 ; A G2 G1 C (Beam Tetrode)
* Sylvania
X1 1 2 3 4 PENTODE MU=8.77 EX=1.265 KG1=1210.3 KP=47.50 KG2=4500 KVB=11.6 VCT=0.00 CCG=14P CPG1=.85P CCP=12P RGI=1K
.ENDS	6L6GB

******************
.SUBCKT 6L6GC_OLD 1 2 3 4 ; A G2 G1 C (Beam Tetrode)
* Original Koren Model
X1 1 2 3 4 PENTODE MU=8.7 EX=1.35 KG1=1460 KG2=4500 KP=48 KVB=12 CCG=14P CPG1=.85P CCP=12P RGI=1K
.ENDS	6L6GC_OLD

******************
.SUBCKT 6L6GC  1 2 3 4 ; A G2 G1 C (Beam Tetrode)
* GE Data sheet
* library format: LTSpice 02-May-2012
X1 1 2 3 4 PENTODE1 MU=9.96 EX=1.275 KG1=933.0 KG2=3023 KP=37.10 KVB=26.9 VCT=0.00 RGI=1000 CCG=10.0p CPG1=0.600p CCP=6.5p ;
.ENDS    6L6GC

******************
.SUBCKT 6L6WGT 1 2 3 4 ; A G2 G1 C (Beam Tetrode)
* same as 6L6GB
X1 1 2 3 4 PENTODE MU=8.77 EX=1.265 KG1=1210.3 KP=47.50 KG2=4500 KVB=11.6 VCT=0.00 CCG=14P CPG1=.85P CCP=12P RGI=1K
.ENDS	6L6WGT

******************
.SUBCKT 6V6 1 2 3 4 ; A G2 G1 C (Beam Tetrode)
* GE data sheet
* library format: LTSpice 17-Nov-2009
X1 1 2 3 4 6V6-GTA ; call 6V6GTA
.ENDS    6V6

******************
.SUBCKT 6V6-GT 1 2 3 4 ; A G2 G1 C (Beam Tetrode)
* GE data sheet
* library format: LTSpice 17-Nov-2009
X1 1 2 3 4 6V6-GTA ; call 6V6GTA
.ENDS    6V6-GT

******************
.SUBCKT 6V6-GTA  1 2 3 4 ; A G2 G1 C (Beam Tetrode) AKA 6V6 6V6-GT EL90
* GE data sheet
* library format: LTSpice 17-Nov-2009
X1 1 2 3 4 PENTODE1 MU=10.70 EX=1.310 KG1=1672.0 KG2=4500 KP=41.16 KVB=12.7 VCT=0.00 RGI=2000 CCG=4.3p CPG1=0.6p CCP=5.1p ;
.ENDS    6V6-GTA

**************************
** European Valve Types **
**************************

*****************
* Output Triode *
*****************

******************
.SUBCKT 6C33C_OLD 1 2 3 ; A G C	(Triode) ; TWO CATHODES FROM BORBELY, GA 5/96.
* Original Koren Lib
X1 1 2 3 TRIODE MU=3.1 EX=1.4 KG1=163 KP=15 KVB=300 VCT=0.00 RGI=1000 CCG=30.0P  CGP=31.0P CCP=10.5P  ; ADD .7PF TO ADJACENT PINS; .5 TO OTHERS.
.ENDS	6C33C

******************
.SUBCKT 6C33C  1 2 3 ; P G C (Triode)
* Soviet (1970) Using both cathodes ie both heaters working
* library format: LTSpice 02-Jun-2008
X1 1 2 3 TRIODE MU=3.27 EX=1.397 KG1=150.9 KP=13.94 KVB=300.0 VCT=0.00 RGI=1000 CCG=30.0p CGP=31.0p CCP=10.5p ;
.ENDS    6C33C



********************
* Rectifier Diodes *
********************

******************
.SUBCKT EZ40  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law) AKA 6V4
* Philips data book  12-May-2008
X1 1 2 3 DULEREC G=0.730451m
.ENDS    EZ40

******************
.SUBCKT EZ80  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law)
* Philips data book  06-Apr-2014
X1 1 2 3 DULEREC G=0.728923m
.ENDS    EZ80

******************
.SUBCKT EZ81  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law)
* Philips Data Sheet  06-Apr-2014
X1 1 2 3 DULEREC G=1.708538m
.ENDS    EZ81

******************
.SUBCKT EZ90  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law)
* Universal Electronic VadeMecum  06-Apr-2014
X1 1 2 3 DULEREC G=0.702260m
.ENDS    EZ90

******************
.SUBCKT GZ30  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law)
* Universal Electronic VadeMecum  12-May-2008
X1 1 2 3 DULEREC G=1.563635m
.ENDS    GZ30

******************
.SUBCKT GZ31  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law) AKA 5V4G
* Universal Electronic VadeMecum  12-May-2008
X1 1 2 3 DULEREC G=1.428012m
.ENDS    GZ31

******************
.SUBCKT GZ32  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law)
* La Radotechnique  12-May-2008
X1 1 2 3 DULEREC G=1.659731m
.ENDS    GZ32

******************
.SUBCKT GZ33  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law)
* Universal Electronic VadeMecum  12-May-2008
X1 1 2 3 DULEREC G=3.432322m
.ENDS    GZ33

******************
.SUBCKT GZ34  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law)
* Philips / Mullard Data Book 1970  12-May-2008
X1 1 2 3 DULEREC G=3.961806m
.ENDS    GZ34

******************
.SUBCKT GZ37  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law)
* Universal Electronic VadeMecum  12-May-2008
X1 1 2 3 DULEREC G=0.7634m
.ENDS    GZ37

******************
.SUBCKT GZ40  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law)
* Universal Electronic VadeMecum  13-May-2008
X1 1 2 3 DULEREC G=0.516249m
.ENDS    GZ40

******************
.SUBCKT GZ41  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law)
* Universal Electronic VadeMecum  14-May-2008
X1 1 2 3 DULEREC G=0.712983m
.ENDS    GZ41

*****************
* Signal Diodes *
*****************

******************
.SUBCKT EAA91  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law)
* Philips 1970  06-Apr-2014
X1 1 2 3 DULEREC G=2.167491m
.ENDS    EAA91

******************
.SUBCKT EAA901  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law)
* Universal Electronic VadeMecum  06-May-2012
X1 1 2 3 DULEREC G=2.167491m
.ENDS    EAA901

******************
.SUBCKT EB91  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law)
* Universal Electronic VadeMecum  06-May-2012
X1 1 2 3 DULEREC G=2.167491m
.ENDS    EB91

****************
* Triode Diode *
****************

******************
.SUBCKT EAC91D  A C  ; A C (Diode Child-Langmuirs Law)
* Mullard Data sheet  06-May-2012
X1 A C REC2 G=0.227656m Vb=2.456321
.ENDS    EAC91D

******************
.SUBCKT EAC91T  1 2 3 ; P G C (Triode)
* Mullard data book Jan 1969
* library format: LTSpice 07-May-2012
X1 1 2 3 TRIODE MU=40.15 EX=1.262 KG1=889.6 KP=123.41 KVB=300.0 VCT=0.00 RGI=2000 CCG=2.3p CGP=2.2p CCP=1.0p ;
.ENDS    EAC91T

**************************
* Triode Output Pentodes *
**************************


******************
.SUBCKT ECL80P  1 2 3 4 ; A G2 G1 C (Pentode)
* Philips Data book 1951 AKA 6AB8
* library format: LTSpice 05-Feb-2009
X1 1 2 3 4 PENTODE1 MU=39.01 EX=0.925 KG1=228.9 KG2=4500 KP=50.26 KVB=21.2 VCT=0.00 RGI=2000 CCG=6.7p CPG1=0.6p CCP=4.1p ;
.ENDS    ECL80P

******************
.SUBCKT ECL80T  1 2 3 ; P G C (Triode)
* Philips Data book 1951 AKA 6AB8
* library format: LTSpice 05-Feb-2009
X1 1 2 3 TRIODE MU=29.30 EX=1.332 KG1=1443.9 KP=45.50 KVB=300.0 VCT=0.00 RGI=2000 CCG=3.2p CGP=2.7p CCP=1.8p ;
.ENDS    ECL80T

******************
.SUBCKT ECL81P  1 2 3 4 ; A G2 G1 C (Pentode)
* universal vademecum (1960)
* library format: LTSpice 05-Feb-2009
X1 1 2 3 4 PENTODE1 MU=17.51 EX=1.350 KG1=590.8 KG2=4500 KP=209.03 KVB=32.5 VCT=0.00 RGI=2000 CCG=6.7p CPG1=0.6p CCP=4.1p ;
.ENDS    ECL81P

******************
.SUBCKT ECL81T  1 2 3 ; P G C (Triode)
* universal vademecum (1960)
* library format: LTSpice 05-Feb-2009
X1 1 2 3 TRIODE MU=66.31 EX=1.390 KG1=1400.2 KP=369.30 KVB=2.5 VCT=0.50 RGI=2000 CCG=3.2p CGP=2.7p CCP=1.8p ;
.ENDS    ECL81T

******************
.SUBCKT ECL82P  1 2 3 4 ; A G2 G1 C (Pentode)
* Philips Data Book 17-02-1956 AKA 6BM8
* library format: LTSpice 04-Feb-2009
X1 1 2 3 4 PENTODE1 MU=12.19 EX=1.350 KG1=522.0 KG2=4500 KP=38.60 KVB=25.8 VCT=0.00 RGI=2000 CCG=6.7p CPG1=0.6p CCP=4.1p ;
.ENDS    ECL82P

******************
.SUBCKT ECL82T  1 2 3 ; P G C (Triode)
* Philips Data Book 17-02-1956 AKA 6BM8
* library format: LTSpice 04-Feb-2009
X1 1 2 3 TRIODE MU=71.97 EX=1.480 KG1=1481.3 KP=500.37 KVB=0.7 VCT=0.50 RGI=2000 CCG=3.2p CGP=2.7p CCP=1.8p ;
.ENDS    ECL82T

******************
.SUBCKT ECL83P  1 2 3 4 ; A G2 G1 C (Pentode)
* Mullard Data Book 1960
* library format: LTSpice 04-Feb-2009
X1 1 2 3 4 PENTODE1 MU=10.96 EX=1.350 KG1=1249.7 KG2=4500 KP=54.82 KVB=14.5 VCT=0.00 RGI=2000 CCG=6.7p CPG1=0.6p CCP=4.1p ;
.ENDS    ECL83P

******************
.SUBCKT ECL83T  1 2 3 ; P G C (Triode)
* universal vademecum (1960)
* library format: LTSpice 04-Feb-2009
X1 1 2 3 TRIODE MU=119.15 EX=1.321 KG1=732.5 KP=305.21 KVB=1.8 VCT=0.50 RGI=2000 CCG=3.2p CGP=2.7p CCP=1.8p ;
.ENDS    ECL83T

******************
.SUBCKT ECL84P  1 2 3 4 ; A G2 G1 C (Pentode)
* Philips Data Book sept 1968 AKA 6DX8
* library format: LTSpice 04-Feb-2009
X1 1 2 3 4 PENTODE1 MU=43.66 EX=1.350 KG1=344.3 KG2=4500 KP=201.06 KVB=26.0 VCT=0.00 RGI=2000 CCG=6.7p CPG1=0.6p CCP=4.1p ;
.ENDS    ECL84P

******************
.SUBCKT ECL84T  1 2 3 ; P G C (Triode)
* Philips Data Book sept 1968 AKA 6DX8
* library format: LTSpice 03-Feb-2009
X1 1 2 3 TRIODE MU=87.85 EX=1.507 KG1=473.2 KP=343.45 KVB=300.0 VCT=0.00 RGI=2000 CCG=3.2p CGP=2.7p CCP=1.8p ;
.ENDS    ECL84T

******************
.SUBCKT ECL85P  1 2 3 4 ; A G2 G1 C (Pentode)
* Philips Data Book Jan 1960 AKA 6GV8
* library format: LTSpice 03-Feb-2009
X1 1 2 3 4 PENTODE1 MU=9.35 EX=1.350 KG1=556.4 KG2=4500 KP=35.28 KVB=21.3 VCT=0.00 RGI=2000 CCG=6.7p CPG1=0.6p CCP=4.1p ;
.ENDS    ECL85P

******************
.SUBCKT ECL85T  1 2 3 ; P G C (Triode)
* Philips Data Book Jan 1960 AKA 6GV8
* library format: LTSpice 03-Feb-2009
X1 1 2 3 TRIODE MU=56.54 EX=1.608 KG1=719.6 KP=247.12 KVB=3.0 VCT=0.50 RGI=2000 CCG=3.2p CGP=2.7p CCP=1.8p ;
.ENDS    ECL85T

******************
.SUBCKT ECL86P  1 2 3 4 ; A G2 G1 C (Pentode)
* Philips Data Book Jan 1970 AKA 6GW8
* library format: LTSpice 03-Feb-2009
X1 1 2 3 4 PENTODE1 MU=23.15 EX=1.350 KG1=479.1 KG2=4500 KP=128.94 KVB=36.0 VCT=0.00 RGI=2000 CCG=6.7p CPG1=0.6p CCP=4.1p ;
.ENDS    ECL86P

******************
.SUBCKT ECL86T  1 2 3 ; P G C (Triode)
* Philips Data Book Jan 1970 AKA 6GW8
* library format: LTSpice 03-Feb-2009
X1 1 2 3 TRIODE MU=102.92 EX=1.425 KG1=1754.6 KP=1098.83 KVB=0.5 VCT=0.50 RGI=2000 CCG=3.2p CGP=2.7p CCP=1.8p ;
.ENDS    ECL86T

******************
.SUBCKT ECL802T  1 2 3 ; P G C (Triode)  ; TRIODE SECTION
* Call Equiverlent AKA ECL85
X1 1 2 3 ECL85T ; same as ECL85T
.ENDS    ECL802T

******************
.SUBCKT ECL802P 1 2 3 4 ; A G2 G1 C (Pentode)	; PENTODE SECTION
* Call Equiverlent AKA ECL85
X1 1 2 3 4 ECL85P ; same as ECL85P
.ENDS	ECL802P

******************
.SUBCKT ECL802T  1 2 3 ; P G C (Triode)  ; TRIODE SECTION
* Call Equiverlent AKA ECL85
X1 1 2 3 ECL85T ; same as ECL85T
.ENDS    ECL802T

******************
.SUBCKT ECL805P 1 2 3 4 ; A G2 G1 C (Pentode)	; PENTODE SECTION
* Call Equiverlent AKA ECL85
X1 1 2 3 4 ECL85P ; same as ECL85P
.ENDS	ECL805P

******************
.SUBCKT ECL805T  1 2 3 ; P G C (Triode)  ; TRIODE SECTION
* Call Equiverlent AKA ECL85
X1 1 2 3 ECL85T ; same as ECL85T
.ENDS    ECL805T

********************************
* Triode small signal Pentodes *
********************************

******************
.SUBCKT ECF80P  1 2 3 4 ; A G2 G1 C (Pentode)
* Philips data sheet AKA 6BL8
* library format: LTSpice 31-May-2008
X1 1 2 3 4 PENTODE1 MU=46.13 EX=1.350 KG1=688.5 KG2=4500 KP=149.94 KVB=8.0 VCT=0.00 RGI=2000 CCG=5.7p CPG1=0.6p CCP=4.1p ;
.ENDS    ECF80P

******************
.SUBCKT ECF80T  1 2 3 ; P G C (Triode)
* Philips data sheet AKA 6AX8 6BL8 P
* library format: LTSpice 29-Apr-2012
X1 1 2 3 TRIODE MU=22.63 EX=1.318 KG1=624.8 KP=72.36 KVB=578.3 VCT=0.50 RGI=2000 CCG=3.0p CGP=2.2p CCP=2.3p ;
.ENDS    ECF80T

******************
.SUBCKT ECF82P  1 2 3 4 ; A G2 G1 C (Pentode)
* Universal Vademecum (1960) AKA 6U8
* library format: LTSpice 31-May-2008
X1 1 2 3 4 PENTODE1 MU=37.97 EX=1.350 KG1=849.8 KG2=4500 KP=90.97 KVB=20.1 VCT=0.00 RGI=2000 CCG=5.7p CPG1=0.6p CCP=4.1p ;
.ENDS    ECF82P

******************
.SUBCKT ECF82T  1 2 3 ; P G C (Triode)
* WF data sheet AKA 6U8
* library format: LTSpice 31-May-2008
X1 1 2 3 TRIODE MU=49.87 EX=1.255 KG1=323.2 KP=106.38 KVB=300.0 VCT=0.00 RGI=2000 CCG=3.0p CGP=2.2p CCP=2.3p ;
.ENDS    ECF82T

******************
.SUBCKT ECF83P  1 2 3 4 ; A G2 G1 C (Pentode)
* Universal Vademecum (1960)
* library format: LTSpice 31-May-2008
X1 1 2 3 4 PENTODE1 MU=12.24 EX=1.350 KG1=2401.0 KG2=4500 KP=27.36 KVB=23.5 VCT=0.00 RGI=2000 CCG=5.7p CPG1=0.6p CCP=4.1p ;
.ENDS    ECF83P

******************
.SUBCKT ECF83T  1 2 3 ; P G C (Triode)
* Universal Vademecum (1960)
* library format: LTSpice 31-May-2008
X1 1 2 3 TRIODE MU=11.83 EX=1.052 KG1=521.1 KP=69.30 KVB=300.0 VCT=0.00 RGI=2000 CCG=3.2p CGP=3.5p CCP=3.1p ;
.ENDS    ECF83T

******************
.SUBCKT ECF86P  1 2 3 4 ; A G2 G1 C (Pentode)
* Sylvania Technical Manual AKA 6HG8
* library format: LTSpice 31-May-2008
X1 1 2 3 4 PENTODE1 MU=64.17 EX=1.350 KG1=328.7 KG2=4500 KP=394.31 KVB=26.0 VCT=0.00 RGI=2000 CCG=6.7p CPG1=0.6p CCP=4.1p ;
.ENDS    ECF86P

******************
.SUBCKT ECF86T  1 2 3 ; P G C (Triode)
* Mazda Belvu Data Book  AKA 6HG8
* library format: LTSpice 31-May-2008
X1 1 2 3 TRIODE MU=16.08 EX=1.162 KG1=601.4 KP=79.68 KVB=300.0 VCT=0.00 RGI=2000 CCG=3.2p CGP=2.7p CCP=1.8p ;
.ENDS    ECF86T

************************
* Small Signal Triodes *
************************

******************
.SUBCKT EC41  1 2 3 ; P G C (Triode)
* Mullard data book 1968 AKA 6R4
* library format: LTSpice 18-Sep-2011
X1 1 2 3 TRIODE MU=16.26 EX=1.295 KG1=868.4 KP=80.50 KVB=1009.9 VCT=0.00 RGI=2000 CCG=1.8p CGP=1.6p CCP=0.7p ;
.ENDS    EC41

******************
.SUBCKT EC80  1 2 3 ; P G C (Triode)
* Mullard data book Jan 1969
* library format: LTSpice 08-May-2012
X1 1 2 3 TRIODE MU=122.22 EX=2.043 KG1=317.3 KP=141.52 KVB=300.0 VCT=0.00 RGI=2000 CCG=5.1p CGP=3.4p CCP=0.1p ;
.ENDS    EC80

******************
.SUBCKT EC81  1 2 3 ; P G C (Triode)
* Mullard data book 1968 AKA 6R4
* library format: LTSpice 18-Sep-2011
X1 1 2 3 TRIODE MU=16.26 EX=1.295 KG1=868.4 KP=80.50 KVB=1009.9 VCT=0.00 RGI=2000 CCG=1.8p CGP=1.6p CCP=0.7p ;
.ENDS    EC81

******************
.SUBCKT E80CC  1 2 3 ; P G C (Triode)
* Philips data sheet Dec 1968
* library format: LTSpice 31-May-2008
X1 1 2 3 TRIODE MU=32.74 EX=1.468 KG1=2447.9 KP=235.61 KVB=2119.4 VCT=0.50 RGI=2000 CCG=3.0p CGP=2.2p CCP=2.3p ;
.ENDS    E80CC

******************
.SUBCKT ECC81  1 2 3 ; P G C (Triode)
* Mullard data book Jan 1969 12AT7
* library format: LTSpice 31-May-2008
X1 1 2 3 TRIODE MU=77.09 EX=1.077 KG1=320.1 KP=231.05 KVB=300.0 VCT=0.00 RGI=2000 CCG=2.3p CGP=2.2p CCP=1.0p ;
.ENDS    ECC81

******************
.SUBCKT ECC82  1 2 3 ; P G C (Triode)
* Mullard data book Jan 1969 AKA 12AU7A 12AU7
* library format: LTSpice 31-May-2008
X1 1 2 3 TRIODE MU=19.98 EX=1.291 KG1=1359.0 KP=87.34 KVB=300.0 VCT=0.00 RGI=2000 CCG=2.3p CGP=2.2p CCP=1.0p ;
.ENDS    ECC82

******************
.SUBCKT ECC83  1 2 3 ; P G C (Triode)
* Mullard data sheet 1970 AKA 12AX7A 7025
* library format: LTSpice 07-May-2012
X1 1 2 3 TRIODE MU=99.95 EX=1.431 KG1=1659.3 KP=688.57 KVB=284.1 VCT=0.50 RGI=2000 CCG=2.3p CGP=2.4p CCP=0.9p ;
.ENDS    ECC83

******************
.SUBCKT ECC84  1 2 3 ; P G C (Triode)
* Philips data book 1955
* library format: LTSpice 31-May-2008
X1 1 2 3 TRIODE MU=27.76 EX=1.309 KG1=492.0 KP=95.80 KVB=379.2 VCT=0.50 RGI=2000 CCG=2.8p CGP=1.9p CCP=1.0p ;
.ENDS    ECC84

******************
.SUBCKT ECC85  1 2 3 ; P G C (Triode)
* Philips data book 1954
* library format: LTSpice 31-May-2008
X1 1 2 3 TRIODE MU=69.50 EX=1.481 KG1=551.4 KP=224.40 KVB=2689.3 VCT=0.50 RGI=2000 CCG=2.8p CGP=3.7p CCP=1.0p ;
.ENDS    ECC85

******************
.SUBCKT ECC86  1 2 3 ; P G C (Triode)
* Philips data book 1959
* library format: LTSpice 31-May-2008
X1 1 2 3 TRIODE MU=29.91 EX=1.596 KG1=294.6 KP=48.11 KVB=210.6 VCT=0.50 RGI=2000 CCG=3.7p CGP=1.8p CCP=2.3p ;
.ENDS    ECC86

******************
.SUBCKT ECC87  1 2 3 ; P G C (Triode)
* Same as E80CC
* library format: LTSpice 31-May-2008
X1 1 2 3 E80CC
.ENDS    ECC87

******************
.SUBCKT ECC88  1 2 3 ; P G C (Triode)
* Philips Data sheet March 1957 AKA 6DJ8
* library format: LTSpice 01-Jun-2008
X1 1 2 3 TRIODE MU=31.04 EX=1.069 KG1=210.9 KP=369.74 KVB=300.0 VCT=0.00 RGI=2000 CCG=3.7p CGP=2.3p CCP=2.2p ;
.ENDS    ECC88

******************
.SUBCKT E88CC  1 2 3 ; P G C (Triode)
* Mullard Data sheet December 1968 AKA 6DJ8, ECC88, 6922
* library format: LTSpice 31-May-2008
X1 1 2 3 TRIODE MU=35.56 EX=1.134 KG1=196.7 KP=278.19 KVB=300.0 VCT=0.00 RGI=2000 CCG=3.7p CGP=2.3p CCP=2.2p ;
.ENDS    E88CC

******************
.SUBCKT ECC801S  1 2 3 ; P G C (Triode)
* Telefunken Data Sheet AKA 6201
* library format: LTSpice 01-Jun-2008
X1 1 2 3 TRIODE MU=77.15 EX=1.078 KG1=320.0 KP=230.75 KVB=300.0 VCT=0.00 RGI=2000 CCG=2.3p CGP=2.2p CCP=1.0p ;
.ENDS    ECC801S

******************
.SUBCKT ECC802S  1 2 3 ; P G C (Triode)
* Telefunken Data sheet AKA 6189
* library format: LTSpice 01-Jun-2008
X1 1 2 3 TRIODE MU=24.10 EX=1.254 KG1=1023.1 KP=65.28 KVB=300.0 VCT=0.00 RGI=2000 CCG=2.3p CGP=2.2p CCP=1.0p ;
.ENDS    ECC802S

******************
.SUBCKT ECC803S  1 2 3 ; P G C (Triode)
* Telefunken Data sheet AKA 6057
* library format: LTSpice 01-Jun-2008
X1 1 2 3 TRIODE MU=98.32 EX=1.456 KG1=1722.8 KP=749.41 KVB=131.2 VCT=0.50 RGI=2000 CCG=2.3p CGP=2.4p CCP=1.1p ;
.ENDS    ECC803S

******************
.SUBCKT EC90  1 2 3 ; P G C (Triode)
* Mullard data book Jan 1969
* library format: LTSpice 07-May-2012
X1 1 2 3 TRIODE MU=20.98 EX=1.289 KG1=1292.4 KP=80.59 KVB=300.0 VCT=0.00 RGI=2000 CCG=1.5p CGP=1.4p CCP=1.5p ;
.ENDS    EC90

******************
.SUBCKT EC91  1 2 3 ; P G C (Triode)
* Mullard data book Jan 1969
* library format: LTSpice 07-May-2012
X1 1 2 3 TRIODE MU=103.54 EX=1.170 KG1=215.0 KP=385.80 KVB=300.0 VCT=0.00 RGI=2000 CCG=8.5p CGP=2.5p CCP=0.2p ;
.ENDS    EC91

******************
.SUBCKT EC92  1 2 3 ; P G C (Triode)
* Mullard data book Jan 1969
* library format: LTSpice 07-May-2012
X1 1 2 3 ECC81
.ENDS    EC92



*************************************
* Small Signal and Vary Mu Pentodes *
*************************************

******************
.SUBCKT EF80  1 2 3 4 ; A G2 G1 C (Pentode)
* Philips data sheet
* library format: LTSpice 18-Apr-2010
X1 1 2 3 4 PENTODE1 MU=54.65 EX=1.105 KG1=271.7 KG2=449 KP=268.91 KVB=58.0 VCT=0.00 RGI=2000 CCG=6.9p CPG1=0.007p CCP=3.1p ;
.ENDS    EF80

******************
.SUBCKT EF83  1 2 3 4 ; A G2 G1 C (Pentode)
* Philips data sheet
* library format: LTSpice 30-May-2008
X1 1 2 3 4 PENTODE1 MU=12.01 EX=1.350 KG1=2830.0 KG2=3895 KP=35.24 KVB=39.1 VCT=0.00 RGI=2000 CCG=4.5p CPG1=0.050p CCP=5.5p ;
.ENDS    EF83

******************
.SUBCKT EF85  1 2 3 4 ; A G2 G1 C (Pentode)
* La RadioTechique
* library format: LTSpice 30-May-2008
X1 1 2 3 4 PENTODE2 MU=22.39 EX=1.350 KG1=974.2 KG2=1570 KP=160.84 KVB=40.9 VCT=0.00 RGI=2000 CCG=4.5p CPG1=0.6p CCP=5.6p ;
.ENDS    EF85

******************
.SUBCKT EF86  1 2 3 4 ; A G2 G1 C (Pentode)
* Philips data sheet AKA 6CF8 and 6267 Z729 EF806
* library format: LTSpice 02-Jun-2008
X1 1 2 3 4 PENTODE1 MU=34.90 EX=1.350 KG1=2648.1 KG2=4627 KP=222.06 KVB=4.7 VCT=0.00 RGI=2000 CCG=4.3p CPG1=0.6p CCP=5.1p ;
.ENDS    EF86

******************
.SUBCKT EF89  1 2 3 4 ; A G2 G1 C (Pentode)
* La Radiotechnique AKA 6DA6
* library format: LTSpice 30-May-2008
X1 1 2 3 4 PENTODE1 MU=30.52 EX=1.350 KG1=926.7 KG2=4500 KP=39.49 KVB=23.6 VCT=0.00 RGI=2000 CCG=5.5p CPG1=0.0p CCP=5.1p ;
.ENDS    EF89

******************
.SUBCKT EF806  1 2 3 4 ; A G2 G1 C (Pentode)
* Philips data sheet AKA 6CF8 and 6267 Z729
* library format: LTSpice 02-Jun-2008
X1 1 2 3 4 EF86 ;
.ENDS    EF806

******************
.SUBCKT Z719  1 2 3 4 ; A G2 G1 C (Pentode)
* Philips data sheet AKA EF80
* library format: LTSpice 02-Jun-2008
X1 1 2 3 4 EF80 ;
.ENDS    Z719

******************
.SUBCKT Z729  1 2 3 4 ; A G2 G1 C (Pentode)
* Philips data sheet AKA 6CF8 and 6267 Z729 EF806
* library format: LTSpice 02-Jun-2008
X1 1 2 3 4 EF86 ;
.ENDS    Z729

******************
.SUBCKT EF91  1 2 3 4 ; A G2 G1 C (Pentode)
* Mullard
* library format: LTSpice 18-Apr-2010
X1 1 2 3 4 PENTODE1 MU=59.59 EX=1.557 KG1=875.9 KG2=1344 K4=1 KP=556.07 KVB=22.1 VCT=0.00 RGI=2000 CCG=5.5p CPG1=0.0p CCP=5.1p ;
.ENDS    EF91

******************
.SUBCKT EF92  1 2 3 4 ; A G2 G1 C (Pentode)
* Mullard data sheet AKA 6CQ6 W77
* library format: LTSpice 31-Oct-2010
X1 1 2 3 4 PENTODE1 MU=42.49 EX=1.557 KG1=2981.3 KG2=2455 KP=55.85 KVB=9.0 VCT=0.00 RGI=2000 CCG=5.5p CPG1=0.002p CCP=5.1p ;
.ENDS    EF92

******************
.SUBCKT EF94  1 2 3 4 ; A G2 G1 C (Pentode)
* GE data sheet AKA 6AU6 6AU6A
* library format: LTSpice 17-Apr-2010
X1 1 2 3 4 6AU6 ;
.ENDS    EF94

******************
.SUBCKT EF95  1 2 3 4 ; A G2 G1 C (Pentode)
* Lorenz Data Sheet AKA 5654 6AK5
* library format: LTSpice 14-Apr-2012
X1 1 2 3 4 PENTODE1 MU=43.98 EX=0.873 KG1=335.2 KG2=539 KP=183.17 KVB=8.8 VCT=0.00 RGI=2000 CCG=4.0p CPG1=0.020p CCP=2.2p ;
.ENDS    EF95

******************
.SUBCKT EF96  1 2 3 4 ; A G2 G1 C (Pentode)
* Tung Sol Data Sheet 1957
* library format: LTSpice 30-Apr-2013
X1 1 2 3 4 PENTODE1 MU=61.69 EX=0.714 KG1=311.7 KG2=425 KP=280.32 KVB=28.9 VCT=0.00 RGI=2000 CCG=6.6p CPG1=0.020p CCP=3.1p ;
.ENDS    EF96

******************
.SUBCKT EF905  1 2 3 4 ; A G2 G1 C (Pentode)
* Lorenz Data Sheet AKA 5654 6AK5
* library format: LTSpice 14-Apr-2012
X1 1 2 3 4 PENTODE1 MU=43.98 EX=0.873 KG1=335.2 KG2=539 KP=183.17 KVB=8.8 VCT=0.00 RGI=2000 CCG=4.0p CPG1=0.020p CCP=2.2p ;
.ENDS    EF905

************************************
* Power Pentodes and Beam Tetrodes *
************************************

******************
.SUBCKT E81L  1 2 3 4 ; A G2 G1 C (Pentode) AKA 6686, EL861
* Philips data sheet
* library format: LTSpice 15-Nov-2009
X1 1 2 3 4 PENTODE1 MU=41.43 EX=1.154 KG1=314.9 KG2=4500 KP=271.62 KVB=17.1 VCT=0.00 RGI=2000 CCG=4.3p CPG1=0.6p CCP=5.1p ;
.ENDS    E81L

******************
.SUBCKT EL34_OLD 1 2 3 4 ; A G2 G1 C (Pentode)	AKA 6CA7
* Original Koren Model
X1 1 2 3 4 PENTODE MU=11 EX=1.35 KG1=650 KG2=4200 KP=60 KVB=24 CCG=15P CPG1=1P CCP=8P RGI=1K
.ENDS	EL34_OLD


******************
.SUBCKT EL34  1 2 3 4 ; A G2 G1 C (PENTODE)
* Mullard Data Book Jan 1969
* library format: LTSpice 20-Apr-2012
X1 1 2 3 4 PENTODE1 MU=14.18 EX=1.175 KG1=282.3 KG2=1147 KP=47.01 KVB=34.6 VCT=0.00 RGI=1000 CCG=15.0p CPG1=1.000p CCP=8.0p ;
.ENDS    EL34

******************
.SUBCKT EL41  1 2 3 4 ; A G2 G1 C (Pentode) AKA BF61 N150 6CK5
* Philips data sheet
* library format: LTSpice 16-Nov-2009
X1 1 2 3 4 EL80 ; Call EL80
.ENDS    EL41

******************
.SUBCKT EL42  1 2 3 4 ; A G2 G1 C (Pentode) AKA BF62 N151
* Philips data sheet
* library format: LTSpice 16-Nov-2009
X1 1 2 3 4 EL85 ; Call EL85
.ENDS    EL42

******************
.SUBCKT EL80  1 2 3 4 ; A G2 G1 C (Pentode)
* Philips data sheet
* library format: LTSpice 16-Nov-2009
X1 1 2 3 4 PENTODE1 MU=24.38 EX=1.084 KG1=292.0 KG2=4500 KP=153.56 KVB=26.2 VCT=0.00 RGI=2000 CCG=4.3p CPG1=0.6p CCP=5.1p ;
.ENDS    EL80

******************
.SUBCKT EL81  1 2 3 4 ; A G2 G1 C (Pentode) AKA 6CJ6 6DR6
* Philips data sheet
* library format: LTSpice 16-Nov-2009
X1 1 2 3 4 PENTODE1 MU=6.38 EX=1.461 KG1=887.2 KG2=4500 KP=305.97 KVB=18.0 VCT=0.00 RGI=2000 CCG=4.3p CPG1=0.6p CCP=5.1p ;
.ENDS    EL81

******************
.SUBCKT EL84  1 2 3 4 ; A G2 G1 C (Pentode)
* Mullard Data Sheet AKA 7189 6BQ5 N709
* library format: LTSpice 02-Jun-2008
X1 1 2 3 4 PENTODE1 MU=21.29 EX=1.240 KG1=401.7 KG2=4500 KP=111.04 KVB=17.9 VCT=0.00 RGI=1000 CCG=10.0p CPG1=0.6p CCP=5.1p ;
.ENDS    EL84

******************
.SUBCKT EL85	1 2 3 4 ; A G2 G1 C (Pentode) AKA 6BN5
* Philips data sheet
* library format: LTSpice 16-Nov-2009
X1 1 2 3 4 PENTODE1 MU=15.00 EX=1.350 KG1=1599.0 KG2=4500 KP=38.28 KVB=18.8 VCT=0.00 RGI=2000 CCG=4.3p CPG1=0.6p CCP=5.1p ;
.ENDS    EL85

******************
.SUBCKT EL90	1 2 3 4 ; A G2 G1 C (Beam Tetrode)
* GE data sheet
* library format: LTSpice 17-Nov-2009
X1 1 2 3 4 6V6-GTA ; call 6V6GTA
.ENDS    EL90

******************
.SUBCKT EL861	1 2 3 4 ; A G2 G1 C (Pentode) AKA 6686, EL861
* Philips data sheet
* Library format: LTSpice 15-Nov-2009
X1 1 2 3 4 E81L ; CALL E81L
.ENDS    EL861

******************
.SUBCKT GU39  1 2 3 4 ; A G2 G1 C (PENTODE)
* RCA
* library format: LTSpice 19-Oct-2011
X1 1 2 3 4 PENTODE1 MU=7.76 EX=1.049 KG1=132.1 KG2=632 KP=58.34 KVB=578.4 VCT=0.00 RGI=200 CCG=80p CPG1=0.7p CCP=29p ;
.ENDS    GU39

******************
.SUBCKT N150	1 2 3 4 ; A G2 G1 C (Pentode) AKA BF61 EL41 6CK5
* Philips data sheet
* library format: LTSpice 16-Nov-2009
X1 1 2 3 4 EL80 ; Call EL80
.ENDS    N150

******************
.SUBCKT N151	1 2 3 4 ; A G2 G1 C (Pentode) AKA BF62 EL42
* Philips data sheet
* library format: LTSpice 16-Nov-2009
X1 1 2 3 4 EL85 ; Call EL85
.ENDS    N51

******************
.SUBCKT N709  1 2 3 4 ; A G2 G1 C (Pentode)
* Mullard Data Sheet AKA 6BQ5 EL84 7189
* library format: LTSpice 02-Jun-2008
X1 1 2 3 4 EL84 ; call EL84
.ENDS    N709

******************
.SUBCKT KT66  1 2 3 4 ; A G2 G1 C (Beam Tetrode)
* M-O Valve Co AKA Genalex
* library format: LTSpice 21-Sep-2008
X1 1 2 3 4 PENTODE1 MU=11.68 EX=1.197 KG1=510.9 KG2=4500 KP=34.89 KVB=22.3 VCT=0.00 RGI=1000 CCG=16.0p CPG1=2.3p CCP=10.0p ;
.ENDS    KT66

******************
.SUBCKT KT77  1 2 3 4 ; A G2 G1 C (Beam Tetrode)
* The M-O Valve Co AKA Genalex
* library format: LTSpice 19-Sep-2008
X1 1 2 3 4 PENTODE1 MU=12.49 EX=1.487 KG1=1058.5 KG2=4500 KP=56.64 KVB=19.4 VCT=0.00 RGI=1000 CCG=16.5p CPG1=1.0p CCP=9.0p ;
.ENDS    KT77

******************
.SUBCKT KT88_OLD 1 2 3 4 ; A G2 G1 C (Beam Tetrode)
* Original Koren Model
X1 1 2 3 4 PENTODE MU=8.8 EX=1.35 KG1=730 KG2=4800 KP=32 KVB=16 VCT=0.00 CCG=14P CPG1=.85P CCP=12P RGI=1K
.ENDS	KT88_OLD

******************
.SUBCKT KT88  1 2 3 4 ; A G2 G1 C (Beam Tetrode)
* The M-O Valve Co AKA Genalex
* library format: LTSpice 19-Sep-2008
X1 1 2 3 4 PENTODE1 MU=12.38 EX=1.246 KG1=340.4 KG2=4500 KP=26.48 KVB=36.5 VCT=0.00 RGI=1000 CCG=14.0p CPG1=0.8p CCP=12.0p ;
.ENDS    KT88

******************
* JJ Tubes       *
******************

******************
.SUBCKT JJECC81  1 2 3 ; P G C (Triode)
* JJ Data Sheet AKA 12AT7
* library format: LTSpice 01-Jun-2008
X1 1 2 3 TRIODE MU=77.15 EX=1.078 KG1=320.0 KP=230.75 KVB=300.0 VCT=0.00 RGI=2000 CCG=2.3p CGP=2.2p CCP=1.0p ;
.ENDS    JJECC81

******************
.SUBCKT JJECC82  1 2 3 ; P G C (Triode)
* JJ Data sheet AKA 12AU7
* library format: LTSpice 01-Jun-2008
X1 1 2 3 TRIODE MU=24.10 EX=1.254 KG1=1023.1 KP=65.28 KVB=300.0 VCT=0.00 RGI=2000 CCG=2.3p CGP=2.2p CCP=1.0p ;
.ENDS    JJECC82

******************
.SUBCKT JJECC83S  1 2 3 ; P G C (Triode)
* JJ Data sheet AKA 12AX7A 7025
* library format: LTSpice 01-Jun-2008
X1 1 2 3 TRIODE MU=98.32 EX=1.456 KG1=1722.8 KP=749.41 KVB=131.2 VCT=0.50 RGI=2000 CCG=2.3p CGP=2.4p CCP=0.9p ;
.ENDS    JJECC83S

******************
.SUBCKT JJECC802S  1 2 3 ; P G C (Triode)
* JJ Data sheet AKA 6189
* library format: LTSpice 01-Jun-2008
X1 1 2 3 TRIODE MU=24.10 EX=1.254 KG1=1023.1 KP=65.28 KVB=300.0 VCT=0.00 RGI=2000 CCG=2.3p CGP=2.2p CCP=1.0p ;
.ENDS    JJECC802S

******************
.SUBCKT JJECC803S  1 2 3 ; P G C (Triode)
* JJ Data sheet AKA 6057
* library format: LTSpice 01-Jun-2008
X1 1 2 3 TRIODE MU=98.32 EX=1.456 KG1=1722.8 KP=749.41 KVB=131.2 VCT=0.50 RGI=2000 CCG=2.3p CGP=2.4p CCP=1.1p ;
.ENDS    JJECC803S

******************
.SUBCKT JJE88CC  1 2 3 ; P G C (Triode)
* JJ Data sheet AKA 6DJ8, ECC88, 6922
* library format: LTSpice 01-Jun-2008
X1 1 2 3 TRIODE MU=35.56 EX=1.134 KG1=196.7 KP=278.19 KVB=300.0 VCT=0.00 RGI=2000 CCG=3.7p CGP=2.3p CCP=2.2p ;
.ENDS    JJE88CC

******************
.SUBCKT JJECC99  1 2 3 ; P G C (Triode)
* JJ Data sheet
* library format: LTSpice 07-Nov-2009
X1 1 2 3 TRIODE MU=23.21 EX=1.482 KG1=460.3 KP=178.32 KVB=300.0 VCT=0.00 RGI=2000 CCG=2.3p CGP=2.2p CCP=1.0p ;
.ENDS    JJECC99

******************
.SUBCKT JJEF806S  1 2 3 4 ; A G2 G1 C (Pentode)
* JJ Data sheet
* library format: LTSpice 30-May-2008
X1 1 2 3 4 PENTODE1 MU=35.04 EX=1.350 KG1=2242.2 KG2=4500 KP=221.86 KVB=7.1 VCT=0.00 RGI=2000 CCG=4.3p CPG1=0.6p CCP=5.1p ;
.ENDS    JJEF806S

******************
.SUBCKT JJ7591S  1 2 3 4 ; A G2 G1 C (Beam Tetrode)
* JJ Data Sheet
* library format: LTSpice 29-May-2008
X1 1 2 3 4 PENTODE1 MU=14.21 EX=1.350 KG1=1124.3 KG2=4500 KP=182.66 KVB=48.8 VCT=0.00 RGI=1000 CCG=10.0p CPG1=0.3p CCP=5.0p ;
.ENDS    JJ7591S

******************
.SUBCKT JJEL84  1 2 3 4 ; A G2 G1 C (Pentode)
* JJ Data Sheet AKA 6BQ5
* library format: LTSpice 29-May-2008
X1 1 2 3 4 PENTODE1 MU=19.56 EX=1.350 KG1=593.0 KG2=4500 KP=131.34 KVB=17.5 VCT=0.00 RGI=1000 CCG=10.0p CPG1=0.6p CCP=5.1p ;
.ENDS    JJEL84

******************
.SUBCKT JJEL509  1 2 3 4 ; A G2 G1 C (Beam Tetrode)
* JJ Data sheet - Warning Non standard valve - check data sheet
* library format: LTSpice 29-May-2008
X1 1 2 3 4 PENTODE1 MU=8.32 EX=1.350 KG1=130.6 KG2=4500 KP=11.62 KVB=24.4 VCT=0.00 RGI=1000 CCG=10.0p CPG1=3.0p CCP=6.5p ;
.ENDS    JJEL509

******************
.SUBCKT JJ2A3  1 2 3 ; P G C (Triode)
* JJ Data sheet
* library format: LTSpice 01-Jun-2008
X1 1 2 3 TRIODE MU=4.30 EX=1.868 KG1=7214.4 KP=23.90 KVB=300.0 VCT=0.00 RGI=1000 CCG=17.0p CGP=11.0p CCP=7.5p ;
.ENDS    JJ2A3

******************
.SUBCKT JJ300B  1 2 3 ; P G C (Triode)
* JJ Data sheet
* library format: LTSpice 01-Jun-2008
X1 1 2 3 TRIODE MU=3.92 EX=1.504 KG1=2140.3 KP=64.28 KVB=300.0 VCT=0.00 RGI=1000 CCG=17.0p CGP=11.0p CCP=7.5p ;
.ENDS    JJ300B

******************
.SUBCKT JJ7027  1 2 3 4 ; A G2 G1 C (Beam Tetrode)
* JJ Data sheet
* library format: LTSpice 18-Sep-2008
X1 1 2 3 4 PENTODE1 MU=13.94 EX=1.063 KG1=320.2 KG2=4500 KP=33.20 KVB=29.6 VCT=0.00 RGI=1000 CCG=10.0p CPG1=0.6p CCP=6.5p ;
.ENDS    JJ7027

******************
.SUBCKT JJ6L6GC  1 2 3 4 ; A G2 G1 C (Beam Tetrode)
* JJ Data sheet
* library format: LTSpice 18-Sep-2008
X1 1 2 3 4 PENTODE1 MU=13.94 EX=1.063 KG1=320.2 KG2=4500 KP=33.20 KVB=29.6 VCT=0.00 RGI=1000 CCG=10.0p CPG1=0.6p CCP=6.5p ;
.ENDS    JJ6L6GC

******************
.SUBCKT JJEL34  1 2 3 4 ; A G2 G1 C (PENTODE)
* JJ Data Sheet
* library format: LTSpice 07-Oct-2008
X1 1 2 3 4 PENTODE1 MU=11.55 EX=1.350 KG1=650.2 KG2=6000 KP=51.85 KVB=25.4 VCT=0.00 RGI=1000 CCG=15.0p CPG1=1.0p CCP=8.0p ;
.ENDS    JJEL34

******************
.SUBCKT JJKT66  1 2 3 4 ; A G2 G1 C (Beam Tetrode)
* JJ Data Sheet
* library format: LTSpice 07-Oct-2008
X1 1 2 3 4 PENTODE1 MU=10.50 EX=1.314 KG1=866.5 KG2=4500 KP=36.12 KVB=25.3 VCT=0.00 RGI=1000 CCG=16.0p CPG1=2.3p CCP=10.0p ;
.ENDS    JJKT66

******************
.SUBCKT JJKT77  1 2 3 4 ; A G2 G1 C (Beam Tetrode)
* JJ Data Sheet
* library format: LTSpice 27-May-2008
X1 1 2 3 4 PENTODE1 MU=13.27 EX=1.350 KG1=460.2 KG2=4500 KP=31.98 KVB=55.7 VCT=0.00 RGI=1000 CCG=16.5p CPG1=1.0p CCP=9.0p ;
.ENDS    JJKT77

******************
.SUBCKT JJKT88  1 2 3 4 ; A G2 G1 C (Beam Tetrode)
* JJ Data Sheet
* library format: LTSpice 19-Sep-2008
X1 1 2 3 4 PENTODE1 MU=12.43 EX=1.218 KG1=315.7 KG2=4500 KP=26.72 KVB=36.1 VCT=0.00 RGI=1000 CCG=14.0p CPG1=0.8p CCP=12.0p ;
.ENDS    JJKT88

******************
* Svetlana Tubes *
******************

******************
.SUBCKT SV300B  1 2 3 ; P G C (Triode)
* Svetlana's Data sheet
* library format: LTSpice 01-Jun-2008
X1 1 2 3 TRIODE MU=3.91 EX=1.301 KG1=943.5 KP=229.85 KVB=300.0 VCT=0.00 RGI=1000 CCG=9.0p CGP=15.0p CCP=7.5p ;
.ENDS    SV300B

******************
.SUBCKT SV6N1P  1 2 3 ; P G C (Triode)
* Svetlana's Data sheet
* library format: LTSpice 01-Jun-2008
X1 1 2 3 TRIODE MU=36.65 EX=1.537 KG1=1020.2 KP=193.29 KVB=300.0 VCT=-0.50 RGI=2000 CCG=3.7p CGP=2.3p CCP=2.2p ;
.ENDS    SV6N1P

******************
.SUBCKT SVEL509  1 2 3 4 ; A G2 G1 C (Beam Tetrode)
* Svetlana's Data sheet AKA 6KG6
* library format: LTSpice 29-May-2008
X1 1 2 3 4 PENTODE1 MU=8.08 EX=1.350 KG1=263.9 KG2=4500 KP=11.68 KVB=42.1 VCT=0.00 RGI=1000 CCG=10.0p CPG1=3.0p CCP=6.5p ;
.ENDS    SVEL509

******************
.SUBCKT SV6L6GC  1 2 3 4 ; A G2 G1 C (Beam Tetrode)
* Svetlana's website
* library format: LTSpice 27-May-2008
X1 1 2 3 4 PENTODE1 MU=11.76 EX=1.350 KG1=996.4 KG2=4500 KP=26.88 KVB=22.1 VCT=0.00 RGI=1000 CCG=10.0p CPG1=0.6p CCP=6.5p ;
.ENDS    SV6L6GC

******************
.SUBCKT SV6550C  1 2 3 4 ; A G2 G1 C (Beam Tetrode)
* Svetlana's website
* library format: LTSpice 27-May-2008
X1 1 2 3 4 PENTODE1 MU=8.33 EX=1.350 KG1=789.8 KG2=4500 KP=44.65 KVB=30.5 VCT=0.00 RGI=1000 CCG=14.0p CPG1=0.8p CCP=12.0p ;
.ENDS    SV6550C

******************
.SUBCKT SVEL34  1 2 3 4 ; A G2 G1 C (Pentode)
* Svetlana's website
* library format: LTSpice 07-Oct-2008
X1 1 2 3 4 PENTODE1 MU=11.52 EX=1.350 KG1=608.9 KG2=4500 KP=41.16 KVB=30.1 VCT=0.00 RGI=1000 CCG=15.0p CPG1=1.0p CCP=8.0p ;
.ENDS    SVEL34

******************
.SUBCKT SVKT88  1 2 3 4 ; A G2 G1 C (Beam Tetrode)
* Svetlana's website
* library format: LTSpice 19-Sep-2008
X1 1 2 3 4 PENTODE1 MU=9.98 EX=0.944 KG1=165.6 KG2=4500 KP=38.07 KVB=35.4 VCT=0.00 RGI=1000 CCG=14.0p CPG1=0.8p CCP=12.0p ;
.ENDS    SVKT88
*

*
***************************
** WW2 Luftwafe MODELS   **
***************************
*

******************
.SUBCKT LD1  1 2 3 ; P G C (Triode)
* Telefunken
* library format: LTSpice 04-Apr-2014
X1 1 2 3 TRIODE MU=13.37 EX=1.496 KG1=2049.8 KP=31.01 KVB=647.3 VCT=0.00 RGI=1000 CCG=1.6p CGP=1.1p CCP=0.7p ;
.ENDS    LD1

******************
.SUBCKT LD2  1 2 3 ; P G C (Triode)
* Telefunken
* library format: LTSpice 04-Apr-2014
X1 1 2 3 TRIODE MU=24.48 EX=1.241 KG1=399.1 KP=270.21 KVB=2936.4 VCT=0.00 RGI=1000 CCG=4.0p CGP=1.5p CCP=3.5p ;
.ENDS    LD2

******************
.SUBCKT LD5  1 2 3 ; P G C (Triode)
* Telefunken
* library format: LTSpice 04-Apr-2014
X1 1 2 3 TRIODE MU=23.32 EX=1.125 KG1=192.2 KP=140.54 KVB=5289.3 VCT=0.00 RGI=1000 CCG=3.8p CGP=2.3p CCP=2.2p ;
.ENDS    LD5

******************
.SUBCKT RD12Tf  1 2 3 ; P G C (Triode)
* Lorenz
* library format: LTSpice 29-Dec-2013
X1 1 2 3 TRIODE MU=51.96 EX=1.400 KG1=420.1 KP=7807.13 KVB=15216.0 VCT=0.00 RGI=2000 CCG=7.7p CGP=4.7p CCP=1.6p ;
.ENDS    RD12Tf

******************
.SUBCKT RG2_4D1  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law)
* Telefunken (1943)  07-Apr-2014
X1 1 2 3 DULEREC G=0.134612m
.ENDS    RG2_4D1

******************
.SUBCKT RG2_4D10  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law)
* Telefunken (1942)  07-Apr-2014
X1 1 2 3 DULEREC G=0.270928m
.ENDS    RG2_4D10

******************
.SUBCKT RG12D2  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law)
* Telefunken (1941)  06-Apr-2014
X1 1 2 3 DULEREC G=0.326915m
.ENDS    RG12D2

******************
.SUBCKT RG12D3  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law)
* Telefunken (1944)  06-Apr-2014
X1 1 2 3 DULEREC G=0.546973m
.ENDS    RG12D3

******************
.SUBCKT RG12D60  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law)
* Telefunken (1940)  06-Apr-2014
X1 1 2 3 DULEREC G=0.529735m
.ENDS    RG12D60

******************
.SUBCKT RG12D300  1 2 3 ; A1 A2 C (Diode Child-Langmuirs Law)
* Telefunken (1943)  06-Apr-2014
X1 1 2 3 DULEREC G=0.993706m
.ENDS    RG12D300

******************
.SUBCKT RL12P10  1 2 3 4 ; A G2 G1 C (Pentode)
* Telefunken data sheet
* library format: LTSpice 12-Apr-2012
X1 1 2 3 4 PENTODE1 MU=23.22 EX=1.215 KG1=496.2 KG2=1212 KP=2597.55 KVB=35.0 VCT=0.00 RGI=1000 CCG=16.5p CPG1=0.050p CCP=10.4p ;
.ENDS    RL12P10

******************
.SUBCKT RL12P35  1 2 3 4 ; A G2 G1 C (Pentode)
* Telefunken data sheet
* library format: LTSpice 22-Sep-2010
X1 1 2 3 4 PENTODE1 MU=5.54 EX=1.215 KG1=1210.7 KG2=2149 KP=13.52 KVB=20.4 VCT=0.00 RGI=1000 CCG=10.5p CPG1=0.05p CCP=16.5p ;
.ENDS    RL12P35

******************
.SUBCKT RL12P50  1 2 3 4 ; A G2 G1 C (Pentode)
* Telefunken data sheet
* library format: LTSpice 11-Apr-2012
X1 1 2 3 4 PENTODE1 MU=6.12 EX=1.215 KG1=757.1 KG2=3917 KP=25.10 KVB=35.3 VCT=0.00 RGI=1000 CCG=14.5p CPG1=0.080p CCP=9.0p ;
.ENDS    RL12P50

******************
.SUBCKT RV2P700  1 2 3 4 ; A G2 G1 C (Pentode)
* Telefunken data sheet
* library format: LTSpice 13-Apr-2012
X1 1 2 3 4 PENTODE1 MU=21.80 EX=1.051 KG1=3035.0 KG2=3847 KP=91.71 KVB=12.9 VCT=0.00 RGI=2000 CCG=3.1p CPG1=0.010p CCP=3.0p ;
.ENDS    RV2P700

******************
.SUBCKT RV2P800  1 2 3 4 ; A G2 G1 C (Pentode)
* Telefunken data sheet
* library format: LTSpice 13-Apr-2012
X1 1 2 3 4 PENTODE1 MU=19.71 EX=1.051 KG1=2475.7 KG2=3973 KP=56.69 KVB=9.8 VCT=0.00 RGI=2000 CCG=13.8p CPG1=0.010p CCP=5.7p ;
.ENDS    RV2P800

******************
.SUBCKT RV2_4P700  1 2 3 4 ; A G2 G1 C (Pentode)
* Telefunken data sheet
* library format: LTSpice 13-Apr-2012
X1 1 2 3 4 PENTODE1 MU=28.57 EX=1.051 KG1=2521.1 KG2=3124 KP=70.73 KVB=9.1 VCT=0.00 RGI=2000 CCG=3.1p CPG1=0.010p CCP=3.0p ;
.ENDS    RV2_4P700

******************
.SUBCKT RV2_4P701  1 2 3 4 ; A G2 G1 C (Pentode)
* Telefunken data sheet
* library format: LTSpice 14-Apr-2012
X1 1 2 3 4 PENTODE1 MU=11.87 EX=1.898 KG1=31293.9 KG2=26444 KP=21.87 KVB=7.9 VCT=0.00 RGI=2000 CCG=3.1p CPG1=0.010p CCP=3.0p ;
.ENDS    RV2_4P701

******************
.SUBCKT RV2_4P1400  1 2 3 4 ; A G2 G1 C (Pentode)
* Telefunken
* library format: LTSpice 14-Apr-2012
X1 1 2 3 4 PENTODE1 MU=35.95 EX=1.350 KG1=1514.0 KG2=4042 KP=168.04 KVB=17.7 VCT=0.00 RGI=2000 CCG=5.0p CPG1=0.030p CCP=6.0p ;
.ENDS    RV2_4P1400

******************
.SUBCKT RV12P2000  1 2 3 4 ; A G2 G1 C (Pentode)
* Telefunken data sheet
* library format: LTSpice 24-Feb-2014
X1 1 2 3 4 PENTODE1 MU=18.59 EX=1.450 KG1=3111.7 KG2=4583 KP=91.92 KVB=11.9 VCT=0.00 RGI=2000 CCG=3.6p CPG1=0.005p CCP=3.4p ;
.ENDS    RV12P2000

******************
.SUBCKT RV12P2001  1 2 3 4 ; A G2 G1 C (Pentode)
* Telefunken data sheet
* library format: LTSpice 24-Feb-2014
X1 1 2 3 4 PENTODE1 MU=25.79 EX=1.051 KG1=1320.1 KG2=1722 KP=47.42 KVB=11.8 VCT=0.00 RGI=2000 CCG=3.6p CPG1=0.005p CCP=3.7p ;
.ENDS    RV12P2001

******************
.SUBCKT RV12P3000  1 2 3 4 ; A G2 G1 C (Pentode)
* Telefunken data sheet
* library format: LTSpice 24-Feb-2014
X1 1 2 3 4 PENTODE1 MU=39.40 EX=1.450 KG1=615.8 KG2=1132 KP=312.92 KVB=19.7 VCT=0.00 RGI=2000 CCG=9.5p CPG1=0.045p CCP=8.0p ;
.ENDS    RV12P3000

******************
.SUBCKT RV12P4000  1 2 3 4 ; A G2 G1 C (Pentode)
* Telefunken
* library format: LTSpice 14-Apr-2012
X1 1 2 3 4 PENTODE1 MU=38.46 EX=1.167 KG1=946.7 KG2=1341 KP=98.10 KVB=5.2 VCT=0.00 RGI=2000 CCG=8.7p CPG1=0.003p CCP=9.9p ;
.ENDS    RV12P4000

******************
.SUBCKT RL12T1  1 2 3 ; P G C (Triode)
* Telefunken 194?
* library format: LTSpice 07-Apr-2014
X1 1 2 3 TRIODE MU=16.28 EX=1.288 KG1=924.9 KP=1578.18 KVB=424.4 VCT=0.00 RGI=2000 CCG=1.7p CGP=1.4p CCP=0.5p ;
.ENDS    RL12T1

******************
.SUBCKT RL12T2  1 2 3 ; P G C (Triode)
* Telefunken 194?
* library format: LTSpice 07-Apr-2014
X1 1 2 3 TRIODE MU=11.72 EX=1.193 KG1=1327.0 KP=79.46 KVB=300.0 VCT=0.00 RGI=2000 CCG=3.2p CGP=3.2p CCP=0.8p ;
.ENDS    RL12T2

******************
.SUBCKT RL12T15  1 2 3 ; P G C (Triode)
* Telefunken 194?
* library format: LTSpice 07-Apr-2014
X1 1 2 3 TRIODE MU=15.22 EX=1.338 KG1=1177.1 KP=136.72 KVB=6020.1 VCT=0.00 RGI=1000 CCG=7.0p CGP=5.0p CCP=5.5p ;
.ENDS    RL12T15

******************
.SUBCKT RL12T75  1 2 3 ; P G C (Triode)
* Telefunken 194?
* library format: LTSpice 07-Apr-2014
X1 1 2 3 TRIODE MU=15.58 EX=1.125 KG1=113.7 KP=129.71 KVB=2492.6 VCT=0.00 RGI=1000 CCG=23.0p CGP=17.0p CCP=14.0p ;
.ENDS    RL12T75

******************
.SUBCKT RL2_4T1  1 2 3 ; P G C (Triode)
* Telefunken 194?
* library format: LTSpice 07-Apr-2014
X1 1 2 3 TRIODE MU=13.89 EX=1.516 KG1=3383.7 KP=63.50 KVB=300.0 VCT=0.00 RGI=2000 CCG=1.6p CGP=1.6p CCP=0.8p ;
.ENDS    RL2_4T1

******************
.SUBCKT RL2_4T4  1 2 3 ; P G C (Triode)
* Telefunken 194?
* library format: LTSpice 07-Apr-2014
X1 1 2 3 TRIODE MU=17.25 EX=1.349 KG1=2700.8 KP=527.50 KVB=977.2 VCT=0.00 RGI=2000 CCG=1.6p CGP=1.6p CCP=0.8p ;
.ENDS    RL2_4T4

*
***************************
** Hexode and Heptodes   **
***************************
*

******************
.SUBCKT EH90  1 2 3 4 5 ; Anode Screen Control1 Cathode Control2 (Hexode)
* Philips data sheet AKA 6CS6
* library format: LTSpice 28-Nov-2013
X1 1 2 3 4 5 HEXODE MU=22.32 EX=1.350 KG1=2196.7 KG2=787 KP=48.74 KVB=1.9 VCT=0.00 RGI=2000 CCG1=5.2p CCG2=6.8p CPG1=0.07p CPG2=0.35p CCP=8.3p ;
.ENDS    EH90

******************
.SUBCKT E91H  1 2 3 4 5 ; Anode Screen Control1 Cathode Control2 (Hexode)
*  AKA 5915 EH900S EH960
* library format: LTSpice 28-Nov-2013
X1 1 2 3 4 5 EH900S ;
.ENDS    E91H

******************
.SUBCKT 5915  1 2 3 4 5 ; Anode Screen Control1 Cathode Control2 (Hexode)
*  AKA E91H EH900 EH960
* library format: LTSpice 28-Nov-2013
X1 1 2 3 4 5 EH900S ;
.ENDS    5915

******************
.SUBCKT EH960  1 2 3 4 5 ; Anode Screen Control1 Cathode Control2 (Hexode)
*  AKA 5915 E91H EH900S EH960
* library format: LTSpice 28-Nov-2013
X1 1 2 3 4 5 EH900S ;
.ENDS    EH960

******************
.SUBCKT EH900S  1 2 3 4 5 ; Anode Screen Control1 Cathode Control2 (Hexode)
* TELEFUNKEN data sheet AKA 5915 E91H EH960
* library format: LTSpice 28-Nov-2013
X1 1 2 3 4 5 HEXODE MU=16.34 EX=1.350 KG1=2706.2 KG2=849 KP=84.14 KVB=7.1 VCT=0.00 RGI=2000 CCG1=5.2p CCG2=6.8p CPG1=0.07p CPG2=0.35p CCP=8.3p ;
.ENDS    EH900S

***********************
**MATHAMATICAL MODELS**
***********************

******************
.SUBCKT TRIODE 1 2 3 ; A G C
E1  7 0 VALUE={V(1,3)/KP*LOG(1+EXP(KP*(1/MU+(V(2,3)+VCT)/SQRT(KVB+V(1,3)*V(1,3)))))}
RE1 7 0 1G
G1  1 3 VALUE={(PWR(V(7,0),EX)+PWRS(V(7,0),EX))/KG1}
RCP 1 3 1G    ; TO AVOID FLOATING NODES IN MU-FOLLOWER
C1  2 3 {CCG}  ; CATHODE-GRID
C2  2 1 {CGP}  ; GRID=PLATE
C3  1 3 {CCP}  ; CATHODE-PLATE
D3  5 3 DX     ; FOR GRID CURRENT
R1  2 5 {RGI}  ; FOR GRID CURRENT
.MODEL DX D(IS=1N RS=1 CJO=10PF TT=1N) ;
.ENDS	TRIODE

******************
.SUBCKT PENTODE 1 2 3 4 ; A G2 G1 C
RE1  7 0  1MEG    ; DUMMY SO NODE 7 HAS 2 CONNECTIONS
E1   7 0  VALUE={V(2,4)/KP*LOG(1+EXP((1/MU+V(3,4)/V(2,4))*KP))}	; E1 BREAKS UP LONG EQUATION FOR G1.
G1   1 4  VALUE={(PWR(V(7),EX)+PWRS(V(7),EX))/KG1*ATAN(V(1,4)/KVB)}
G2   2 4  VALUE={(EXP(EX*(LOG((V(2,4)/MU)+V(3,4)))))/KG2}
*G2   2 4  VALUE={PWR((V(2,4)/MU)+V(3,4), EX )/KG2}
RCP  1 4  1G      ; FOR CONVERGENCE	A  - C
C1   3 4  {CCG}   ; CATHODE-GRID 1	C  - G1
C2   1 3  {CPG1}  ; GRID 1-PLATE	G1 - A
C3   1 4  {CCP}   ; CATHODE-PLATE	A  - C
R1   3 5  {RGI}   ; FOR GRID CURRENT	G1 - 5
D3   5 4  DX      ; FOR GRID CURRENT	5  - C
.MODEL DX D(IS=1N RS=1 CJO=10PF TT=1N) ;
.ENDS PENTODE

******************
.SUBCKT PENTODE1 1 2 3 4 ; A G2 G1 C
RE1  7 0  1MEG    ; DUMMY SO NODE 7 HAS 2 CONNECTIONS
E1   7 0  VALUE={V(2,4)/KP*LOG(1+EXP((1/MU+V(3,4)/V(2,4))*KP))}	; E1 BREAKS UP LONG EQUATION FOR G1.
G1   1 4  VALUE={(PWR(V(7),EX)+PWRS(V(7),EX))/KG1*ATAN(V(1,4)/KVB)}
G2   2 4  VALUE={(EXP(EX*(LOG((V(2,4)/MU)+V(3,4)))))/KG2}
*G2   2 4  VALUE={PWR(if( V(2,4)/MU+V(3,4) < 0 , V(2,4)/MU+V(3,4), 0 ) ,EX )/KG2}
RCP  1 4  1G      ; FOR CONVERGENCE	A  - C
C1   3 4  {CCG}   ; CATHODE-GRID 1	C  - G1
C2   1 3  {CPG1}  ; GRID 1-PLATE	G1 - A
C3   1 4  {CCP}   ; CATHODE-PLATE	A  - C
R1   3 5  {RGI}   ; FOR GRID CURRENT	G1 - 5
D3   5 4  DX      ; FOR GRID CURRENT	5  - C
.MODEL DX D(IS=1N RS=1 CJO=10PF TT=1N) ;
.ENDS PENTODE1

******************
.SUBCKT PENTODE2 1 2 3 4 ; A G2 G1 C
RE1  7 0  1MEG    ; DUMMY SO NODE 7 HAS 2 CONNECTIONS
E1   7 0  VALUE={V(2,4)/KP*LOG(1+EXP((1/MU+V(3,4)/V(2,4))*KP))}	; E1 BREAKS UP LONG EQUATION FOR G1.
* G1   1 4  VALUE={(PWR(V(7),EX)+PWRS(V(7),EX))/KG1*ATAN(V(1,4)/KVB)}
G1   1 4  VALUE={pi/2*(PWR(V(7),EX)+PWRS(V(7),EX))/KG1*(1-exp(-2*V(1,4)/(pi*KVB)))}
G2   2 4  VALUE={(EXP(EX*(LOG((V(2,4)/MU)+V(3,4)))))/KG2}
*G2   2 4  VALUE={PWR(V(2,4)/MU+V(3,4),EX)/KG2}
RCP  1 4  1G      ; FOR CONVERGENCE	A  - C
C1   3 4  {CCG}   ; CATHODE-GRID 1	C  - G1
C2   1 3  {CPG1}  ; GRID 1-PLATE	G1 - A
C3   1 4  {CCP}   ; CATHODE-PLATE	A  - C
R1   3 5  {RGI}   ; FOR GRID CURRENT	G1 - 5
D3   5 4  DX      ; FOR GRID CURRENT	5  - C
.MODEL DX D(IS=1N RS=1 CJO=10PF TT=1N) ;
.ENDS PENTODE2

******************
.SUBCKT PENTODE3 1 2 3 4 ; A G2 G1 C
RE1  7 0  1MEG    ; DUMMY SO NODE 7 HAS 2 CONNECTIONS
E1   7 0  VALUE={V(2,4)/KP*LOG(1+EXP((1/MU+V(3,4)/V(2,4))*KP))}	; E1 BREAKS UP LONG EQUATION FOR G1.
* G1   1 4  VALUE={(PWR(V(7),EX)+PWRS(V(7),EX))/KG1*ATAN(V(1,4)/KVB)}
G1   1 4  VALUE={pi/2*(PWR(V(7),EX)+PWRS(V(7),EX))/KG1*tanh(2*V(1,4)/(pi*KVB))}
G2   2 4  VALUE={(EXP(EX*(LOG((V(2,4)/MU)+V(3,4)))))/KG2}
* G2   2 4  VALUE={PWR(V(2,4)/MU+V(3,4),EX)/KG2}
RCP  1 4  1G      ; FOR CONVERGENCE	A  - C
C1   3 4  {CCG}   ; CATHODE-GRID 1	C  - G1
C2   1 3  {CPG1}  ; GRID 1-PLATE	G1 - A
C3   1 4  {CCP}   ; CATHODE-PLATE	A  - C
R1   3 5  {RGI}   ; FOR GRID CURRENT	G1 - 5
D3   5 4  DX      ; FOR GRID CURRENT	5  - C
.MODEL DX D(IS=1N RS=1 CJO=10PF TT=1N) ;
.ENDS PENTODE3

******************
.SUBCKT HEXODE  1 2 3 4 5 ; A G3 G1 C G2
RE1  7 0  1MEG    ; DUMMY SO NODE 7 HAS 2 CONNECTIONS
E1   7 0  VALUE={V(2,4)/KP*LOG(1+EXP((1/MU+(V(3,4)+V(5,4))/V(2,4))*KP))} ; E1 BREAKS UP LONG
G1   1 4  VALUE={(PWR(V(7),EX)+PWRS(V(7),EX))/KG1*ATAN(V(1,4)/KVB)}
G2   2 4  VALUE={(EXP(EX*(LOG((V(2,4)/MU)+(V(3,4)+V(5,4))))))/KG2}
*G2   2 4  VALUE={PWR((V(2,4)/MU)+(V(3,4)+V(5,4)), EX )/KG2}
RCP  1 4  1G       ; FOR CONVERGENCE             A  - C
C1   3 4  {CCG1}   ; CATHODE-GRID 1              C  - G1
C2   5 4  {CCG2}   ; CATHODE-GRID 2              C  - G2
C3   1 3  {CPG1}   ; GRID 1-PLATE                G1 - A
C4   1 5  {CPG2}   ; GRID 2-PLATE                G2 - A
C5   1 4  {CCP}    ; CATHODE-PLATE               A  - C
RG1   3 8  {RGI}   ; FOR GRID CURRENT            G1 - 8
DG1   8 4  DX      ; FOR GRID CURRENT            8  - C
RG2   5 9  {RGI}   ; FOR GRID CURRENT            G2 - 9
DG2   9 4  DX      ; FOR GRID CURRENT            9  - C
.MODEL DX D(IS=1N RS=1 CJO=10PF TT=1N) ;
.ENDS HEXODE



******************
*
******************
* (Diode - Child-Langmuirs Law)
*               anode 1
*               | anode 2
*               | | cathode
*               | | |
.SUBCKT DULEREC 1 2 3
B1	1	3	I=if( V(1,3)>0, {G}*(V(1,3)**1.5), 0)
B2	2	3	I=if( V(2,3)>0, {G}*(V(2,3)**1.5), 0)
.ENDS DULEREC

******************
* (Diode - Child-Langmuirs Law)
*           anode
*           | cathode
*           | |
.SUBCKT REC 1 2
B1	1	2	I=if( V(1,2)>0, {G}*(V(1,2)**1.5), 0)
.ENDS REC

******************
* (Diode - Child-Langmuirs Law + contact potential)
*            anode
*            | cathode
*            | |
.SUBCKT REC2 A C
RE	7	0	1MEG    ; DUMMY SO NODE 7 HAS 2 CONNECTIONS
E1	7	0	VALUE={g}*POW(V(a,c)+{Vb},1.5)
G1	a	c	VALUE={if(V(a,c)+{Vb}>0, V(7), 0)}
R1	A	C	1T
.ENDS

******************
** Transformers **
******************

******************
.SUBCKT PAT-4006-CFB 1 2 3 4 5 6 7 8 9 10 11
* PLITRON PAT-4006-CFB OUTPUT TRANSFORMER 2KOHM UL PRIMARY
* OL NUMBERS CORRESPOND TO TRANSFORMER SCHEMATIC.
.PARAM PRIML=392.5     ; TOTAL PRIMARY L (FROM SPECS).
.PARAM LRATIO={5/2000} ; INDUCTANCE RATIO: (5 OHMS)/(PRIMARY).
.PARAM QFCTR=400000     ; Q-FACTOR: PRIMARY SHUNT L/LEAKAGE L.
LP1 1 2   {PRIML*.09}     ; PRIMARY
LP2 2 3   {PRIML*.04}
LP3 3 4   {PRIML*.04}
LP4 4 5   {PRIML*.09}
CP1 1 5   .342NF      ; CAPACITANCE FROM SPECS
LP5 8 7   {PRIML*LRATIO/4}  ; 1/2 SPEAKER SECONDARY
LP6 7 6   {PRIML*LRATIO/4}  ; " "
LP7 11 10 {PRIML*LRATIO}    ; 1/2 FBK WINDING
LP8 10 9  {PRIML*LRATIO}    ; " "
KALL LP1 LP2 LP3 LP4 LP5 LP6 LP7 LP8 .9999987 ; 1-1/(2*403600) AWESOME!
.ENDS PAT-4006-CFB

******************
.SUBCKT DYNA_OUTPUT_XFRMR 1 2 3 4 5 6 7 8 9  ; PARAMETERS FOR MARK 3:
+PARAMS: LPRIM=60 LLKG=.040 RPRIM=125 CPRIM=1.04NF LRATIO={4/4300}

* ERIC BARBOUR ARTICLE:  ~233H TOTAL PRIMARY L FOR MARK 3.
* MARK 3: LPRIM=60 LLKG=.040 RPRIM=125 CPRIM=1.04NF LRATIO={4/4300}

* LPRIM  IS THE TOTAL PRIMARY L (VARIES WITH MEASUREMENT).
* LLKG   IS THE LEAKAGE L (MEASURABLE: CONSISTENT).
* RPRIM  IS THE TOTAL PRIMARY R.
* CPRIM  IS THE MEASURED PRIMARY CAPACITANCE.
* LRATIO IS THE INDUCTANCE RATIO: (4 OHMS)/(PRIMARY Z).

.PARAM QFCTR={LPRIM/LLKG}  ; Q-FACTOR.
CS1 1 5    {CPRIM}     ; PRIMARY CAPACITANCE
RS1 1 5    300K        ; SHUNT R FOR HIGH FREQUENCY EFFECTS.
LP1 1 12   {LPRIM*.09} ; .7164H  ; PRIMARY
RP1 12 2   {RPRIM*.5}
LP2 2 3    {LPRIM*.04} ; .3184H
LP3 3 4    {LPRIM*.04}
LP4 4 45   {LPRIM*.09}
RP4 45 5   {RPRIM*.5}
LP5 7 6    {.34315*LPRIM*LRATIO} ; 8-16  OHM WINDING: (2-SQRT(2))^2
LP6 8 7    {.17157*LPRIM*LRATIO} ; 4-8   OHM WINDING: (SQRT(2)-1)^2
LP7 9 8    {LPRIM*LRATIO}        ; COM-4 OHM WINDING
KALL LP1 LP2 LP3 LP4 LP5 LP6 LP7 {1-1/(2*QFCTR)}  ; COUPLING
.ENDS DYNA_OUTPUT_XFRMR

*model D1N5292  anode
*               | cathode
*               | |
.subckt D1N5292 1 2
  j1 1 2 2 jx
  .model   jx   NJF(Beta=134u Betatce=-.5 Rd=1 Rs=0 Lambda=366.1u Vto=-2.149
+               Vtotc=-2.5m N=2 Xti=3 Cgd=3p Is=10f M=.5 Pb=1 Fc=.5 Af=1)
*               Motorola        pid=NKL         case=DO7
*               88-07-25 bam    POVmax=100
*               88-12-16 pwt
.ends

*model D1N5295  anode
*               | cathode
*               | |
.subckt D1N5295 1 2
  j1 1 2 2 jx
  .model   jx   NJF(Beta=277.5u Betatce=-.5 Rd=1 Rs=0 Lambda=203.3u Vto=-1.721
+               Vtotc=-2.5m N=2 Xti=3 Cgd=4.5p Is=10f M=.5 Pb=1 Fc=.5 Af=1)
*               Motorola        pid=NKM         case=DO7
*               88-07-25 bam    POVmax=100
*               88-12-16 pwt
.ends D1N5295

*  .PARAM statements:  The parameter to be stepped
*  in the PSPICE schematic is PAR1.  (PAR1 is a global variable set in
*  Analysis...  Setup...   Parametric... in the PSPICE schematic program.)

* .PARAM PAR1=1.                        ; NORMAL SETTING IF NOT STEPPED.
* .PARAM PARM={1-PAR1}
* .STEP PARAM PFRAC 0 1 .25  ; -1 1 1 ;  0 1 .25
* .PARAM PARP={ .5*(PAR1+ABS(PAR1))}    ; =  PAR1  IF PAR1 >= 0
* .PARAM PARN={-.5*(PAR1-ABS(PAR1))}    ; = |PAR1| IF PAR1 <= 0
*  PARTX IS FOR THE PAS TREBLE CONTROL.
* .PARAM PAR2={.5*(1-COS(3.141593*PAR1))}
* .PARAM PARTX={(EXP(4.60517*PAR1)-1)/99}
